
/**********************************************
* AnimationItem Object:
* HOLDS A CANVAS ITEM, the default values and an array of KeyFrames.
/**********************************************/
function AnimationItem(item, x, y, a, s)
{
	this.canvasItem = item;
	this.startX = x;
	this.startY = y;
	this.startAlpha = a;
	this.startScale = s;
	this.startColor = item.color;
	
	this.keyFrames = []; /* Array of KeyFrame objects - Needs to be stored in order of startTime, and cant have times overlap	*/
}

/**********************************************
* JS Item Object:
* HOLDS An object with code and keyframes that the code will execute between.
/**********************************************/
function JSItem(id, codeString)
{
	this.id = id;
	this.code = codeString;
	
	this.keyFrames = []; /* Array of KeyFrame objects - Needs to be stored in order of startTime, and cant have times overlap	*/
}

/*
************************************************************************************************************
ANIMATION OBJECTS:
************************************************************************************************************
*/

/**********************************************
* Key Frame Object:
* HOLDS A START TIME, and values for the keyframe canvasItem.
* Can compare 2 keyframes to get the animation/translation between them.
/**********************************************/
function KeyFrame(start, x, y, a, sX, sY)
{
	this.startTime = start;
	this.x = x;
	this.y = y;
	this.alpha = a;
	this.scaleX = sX;
	this.scaleY = sY;
	this.color = false;
}

function KeyFrame(start, x, y, a, sX, sY, color)
{
	this.startTime = start;
	this.x = x;
	this.y = y;
	this.alpha = a;
	this.scaleX = sX;
	this.scaleY = sY;
	this.color = color;
}

function jsKeyFrame(start, end, codeString)
{
	this.startTime = start;
	this.endTime = end;
	this.code = codeString;
	this.executed = false;
}

/**********************************************
* processAnimation Function:
* Takes an animation item.  Loops through that animationItem.keyFrame
* For Each key Frame, checks to see if there is a next keyFrame if so does a tween between the 2 keyframes.
* If not uses either start or end values based on the time.
/**********************************************/
function processAnimation(animationItem)
{
	/* SET TEMP OBJECT VARIABLES */
	var currKeyFrame;
	var nextKeyFrame;
	var numberOfKeyFrames = animationItem.keyFrames.length;			
	
	/** Loop through canvasItem.keyFrames: **/
	for(var i=0; i<numberOfKeyFrames; i++)
	{
		/* SET  CurrentFrame: */
		currKeyFrame = animationItem.keyFrames[i];
		//console.log("processing frame: " + i)
		
		/** Check if there is another keyframe: **/
		if(i+1 < numberOfKeyFrames)
		{				
			/* SET NEXT FRAME: */
			nextKeyFrame = animationItem.keyFrames[i+1];
			//console.log("processing next frame.")
			
			/* SET PERCENT OF ANIMATION: */
			var percentOfAnimationCompleted = (elapsedTime-currKeyFrame.startTime)/(nextKeyFrame.startTime-currKeyFrame.startTime);
			
			/** IF CURRENT TIME >KEYFRAME HANDLE ANIMATION: **/
			if(elapsedTime > currKeyFrame.startTime && elapsedTime < nextKeyFrame.startTime ) {	
				/** CHECK EACH PROPERTY TO SEE IF IT NEEDS TO BE ANIMATED: **/
				if(currKeyFrame.x != nextKeyFrame.x)
				{
					/* DO X-axis translation: */
					/* x = StartPosition + (Percent of Animation Completed)*(TotalNumber of Pixels to Move) */
					animationItem.canvasItem.x = currKeyFrame.x + percentOfAnimationCompleted*(nextKeyFrame.x-currKeyFrame.x);	
				}
				else {
					animationItem.canvasItem.x = currKeyFrame.x;
				}
				
				if(currKeyFrame.y != nextKeyFrame.y)
				{
					/* DO Y-axis translation: */
					/* y = StartPosition + (Percent of Animation Completed)*(TotalNumber of Pixels to Move) */
					animationItem.canvasItem.y = currKeyFrame.y + percentOfAnimationCompleted*(nextKeyFrame.y-currKeyFrame.y);
				}
				else {
					animationItem.canvasItem.y = currKeyFrame.y;
				}						
				
				if(currKeyFrame.scaleX != nextKeyFrame.scaleX)
				{
					/* DO scale X transition: */
					animationItem.canvasItem.scaleX = currKeyFrame.scaleX + percentOfAnimationCompleted*(nextKeyFrame.scaleX-currKeyFrame.scaleX);
				}
				else {
					animationItem.canvasItem.scaleX = currKeyFrame.scaleX;
				}						
				if(currKeyFrame.scaleY != nextKeyFrame.scaleY)
				{
					/* DO scale Y transition: */
					animationItem.canvasItem.scaleY = currKeyFrame.scaleY + percentOfAnimationCompleted*(nextKeyFrame.scaleY-currKeyFrame.scaleY);
				}
				else {
					animationItem.canvasItem.scaleY = currKeyFrame.scaleY;
				}						
				if(currKeyFrame.alpha != nextKeyFrame.alpha)
				{
					/* DO Alpha transition: */
					animationItem.canvasItem.alpha = currKeyFrame.alpha + percentOfAnimationCompleted*(nextKeyFrame.alpha-currKeyFrame.alpha);
				}
				else {
					animationItem.canvasItem.alpha = currKeyFrame.alpha;
				}
				if(currKeyFrame.color != nextKeyFrame.color)
				{
					/* DO COLOR TRANSITION: */
					/*** THIS SHOULD BE CONVERTED TO A TINT/FILTER - AS THIS DOESNT WORK ON BITMAPS I THINK ***/
					
					/* CHECK IF CURFRAME COLOR IS FALSE - IF SO SET IT TO START ITEM COLOR OR PREVIOUS FRAMES COLOR: */
					if(!currKeyFrame.color)
					{
						currKeyFrame.color = animationItem.startColor;
					}
					
					/* SPLIT THE HEX STRING INTO R G B PARTS: */
					currHex = currKeyFrame.color.replace("#", "");
					currRed = parseInt(currHex.substring(0,2), 16);
					currGreen = parseInt(currHex.substring(2,4), 16);
					currBlue = parseInt(currHex.substring(4,6), 16);
					
					nextHex = nextKeyFrame.color.replace("#", "");
					nextRed = parseInt(nextHex.substring(0,2), 16);
					nextGreen = parseInt(nextHex.substring(2,4), 16);
					nextBlue = parseInt(nextHex.substring(4,6), 16);
					
					/* newRed = (Math.round(Math.abs((currRed-nextRed)/2),0)+Math.min(currRed,nextRed)).toString(16); */
					newRed = (Math.round(currRed + percentOfAnimationCompleted*(nextRed-currRed), 0)).toString(16);
					newGreen = (Math.round(currGreen + percentOfAnimationCompleted*(nextGreen-currGreen), 0)).toString(16);
					newBlue = (Math.round(currBlue + percentOfAnimationCompleted*(nextBlue-currBlue), 0)).toString(16);
					/*
					newGreen = (Math.round(Math.abs((currGreen-nextGreen)/2),0)+Math.min(currGreen,nextGreen)).toString(16);
					newBlue = (Math.round(Math.abs((currBlue-nextBlue)/2),0)+Math.min(currBlue,nextBlue)).toString(16);
					*/
					
					if(newRed.length < 2)
					{
						newRed = "0"+newRed;
					}
					if(newGreen.length < 2)
					{
						newGreen = "0"+newGreen;
					}
					if(newBlue.length < 2)
					{
						newBlue = "0"+newBlue;
					}
					
					//newHexColor = (Math.round(currDecColor + percentOfAnimationCompleted*(nextDecColor-currDecColor), 0)).toString(16);
					
					newHexColor = newRed + "" + newGreen + "" + newBlue;
					
					
					/* 
					console.log("Curr Color: " + currHex + " NextColor: " + nextHex + " New Color: " + newHexColor);
					/* */
					
					animationItem.canvasItem.color = "#"+newHexColor;
				}
				else
				{
					animationItem.canvasItem.color = currKeyFrame.color;
				}
			}
			else {
				/** ELAPSED TIME LESS THAN KEYFRAME START - IF FIRST FRAME SET ITEM PROPERTIES TO START VALUES: **/
				if (i==0)
				{
				
					animationItem.canvasItem.scaleX = animationItem.startScale;
					animationItem.canvasItem.scaleY = animationItem.startScale;
				
					animationItem.canvasItem.x = animationItem.startX;
					animationItem.canvasItem.y = animationItem.startY;
					animationItem.canvasItem.alpha = animationItem.startAlpha;
					animationItem.canvasItem.color = animationItem.startColor;
					
				}
				
			}				
		}
		else {
			/** IF THIS IS THE LAST KEY FRAME CHECK TO SEE IF ELAPSED TIME IS GREATER THAN FRAME START - IF SO USE LAST FRAME VALUES: **/
			if(elapsedTime > currKeyFrame.startTime ) {
				animationItem.canvasItem.x = currKeyFrame.x;
				animationItem.canvasItem.y = currKeyFrame.y;
				animationItem.canvasItem.alpha = currKeyFrame.alpha;
				animationItem.canvasItem.scaleX = currKeyFrame.scaleX;
				animationItem.canvasItem.scaleY = currKeyFrame.scaleY;
				animationItem.canvasItem.color = currKeyFrame.color;
			}
		}
		
	}
	
	//console.log(animationItem.canvasItem.x);
			
}


/**********************************************
* processJS Function:
* Takes a JS item.  Loops through that JS Item.keyFrames
* Checks to see if the time is between start & end & not yet executed: if so it executes its code else set executed false.
/**********************************************/
function processJS(jsItem)
{
	var currKeyFrame;
	var nextKeyFrame;
	var numberOfKeyFrames = jsItem.keyFrames.length;			
	
	/** Loop through jsItem.keyFrames: **/
	for(var i=0; i<numberOfKeyFrames; i++)
	{
		/* SET THE KEYFRAME: */
		currKeyFrame = jsItem.keyFrames[i];
		if(elapsedTime > currKeyFrame.startTime && elapsedTime < currKeyFrame.endTime ) {
			if( currKeyFrame.executed == false) {
				/* EXECUTE THE JS: */
				//console.log("Running JS code...");
				eval(currKeyFrame.code);
				currKeyFrame.executed = true;
			}
		} else {
			currKeyFrame.executed = false;
		}
		
	}
	
}


/** LOOP THROUGH animationItemArray Items FOR EACH ITEM DO ITS KEYFRAME ANIMATIONS: **/
function animationTickEvent(event) {
	/* Loop through the Canvas Items Array: */
	for(var i=0; i<animationItemArray.length; i++) {
						
		/* FOR EACH ITEM CALL processAnimations Function: */
		processAnimation(animationItemArray[i]);				
		
		
	}
	
	for(var i=0; i<jsItemArray.length; i++) {
						
		/* FOR EACH ITEM CALL processAnimations Function: */
		processJS(jsItemArray[i]);	
	}
	
	/* IF CUSTOM TIMELINE & TICKER NOT PAUSED: */
	if (!createjs.Ticker.paused && tickerOn) {
		/* UPDATE THE ELAPSED TIME: */
		elapsedTime = elapsedTime + event.delta;
		
		//console.log(elapsedTime/totalTime);
		
		
		/* SET THE SLIDER VALUE: */
		document.getElementById('progressBar').value = elapsedTime/totalTime*10000*100;
		/* */
		
		/* PAUSE IF COMPLETE, PLAY NEXT IF COMPLETE: */
		
		if (elapsedTime/totalTime>=1) {
			setAnimationPaused(true);
			checkAutoNav();
		}
		
	}
	
	/* CALL UPDATE STAGE: */
	stage.update(event); /* important!! */
}

/** GLOBAL VARIABLES: **/
var stage; /* THE STAGE THAT THE CANVAS IS ADDED ON: */
var animationItemArray = []; /* THE ARRAY OF animationItems - holds each canvasItem that has keyframes - Including Title */
var jsItemArray = []; /* THE ARRAY OF jsItems */
var elapsedTime; /* THE ELAPSED TIME OF THE ANIMATION: */	
var totalTime; /* THE LENGTH OF THE AUDIO THAT IS PLAYING ON THE SLIDE - OR THE TIMELINE (IF NO AUDIO) */
var tickerOn = false;		


/** 
* FUNCTION addElements:
* This adds the slides canvasItems to the Stage, as well as adding them as animationItems to the animationItemArray.
* For each AnimationItem it will also build it's keyFrame Array.
**/
function addElementsExample() {
	
	var tempCanvasItem;
	var tempAnimationItem;
	var tempKeyFrame;
							
	/** EXAMPLE ITEM: **/
	/** CREATE A NEW CANVAS ITEM: **/
	tempCanvasItem = new createjs.Shape();
	/* SET THE VALUES: */
	tempCanvasItem.x = 50; 
	tempCanvasItem.y = 150;
	/* IF SHAPE CALL THE FILL FUNCTION: */
	tempCanvasItem.graphics.beginFill("red").drawRect(0, 0, 40, 40);
		
	/** CREATE AN ANIMATION ITEM AND ADD THE CANVAS ITEM: **/
	tempAnimationItem = new AnimationItem(tempCanvasItem, tempCanvasItem.x, tempCanvasItem.y, 1, 1)
	/* ADD THE ANIMATION ITEM TO THE ITEM ARRAY AS THE NEXT ITEM: */
	animationItemArray[animationItemArray.length] = tempAnimationItem;
	
	/** ADD THE ITEM TO THE CANVAS STAGE: **/
	stage.addChild(animationItemArray[animationItemArray.length-1].canvasItem);
	
	/** SET UP THE KeyFrames ON THE ITEM: **/
	/* Create a new keyFrame: */
	tempKeyFrame = new KeyFrame(2000, tempCanvasItem.x, tempCanvasItem.y, 0.25, 1, 1); /* new KeyFrame(startTime, x-value, y-value, alpha, scale-x, scale-y) */
	/* Add the KeyFrame to the animationItem's keyFrame Array: */
	tempAnimationItem.keyFrames[tempAnimationItem.keyFrames.length] = tempKeyFrame;
	/* Create a new keyFrame: */
	tempKeyFrame = new KeyFrame(5000, tempCanvasItem.x+300, tempCanvasItem.y+300, 0.75, 2, 3);
	/* Add the KeyFrame to the animationItem's keyFrame Array: */
	tempAnimationItem.keyFrames[tempAnimationItem.keyFrames.length] = tempKeyFrame;
	/* Create a new keyFrame: */
	tempKeyFrame = new KeyFrame(8000, tempCanvasItem.x, tempCanvasItem.y+50, 0, 0.5, 0.5);
	/* Add the KeyFrame to the animationItem's keyFrame Array: */
	tempAnimationItem.keyFrames[tempAnimationItem.keyFrames.length] = tempKeyFrame;
	/*** ***/
	
	
	/** EXAMPLE TEXT: **/
	tempCanvasItem = new createjs.Text("This Slide Title Is longer than before!!", "20px Arial", "#ff7700"); 
	tempCanvasItem.x = stage.canvas.width/2; 
	tempCanvasItem.y = stage.canvas.height/2; 
	tempCanvasItem.textAlign = "center"; 
	tempCanvasItem.textBaseline = "alphabetic";
	
	tempAnimationItem = new AnimationItem(tempCanvasItem, tempCanvasItem.x, tempCanvasItem.y, 0, 1)
	/* ADD THE ANIMATION ITEM TO THE ITEM ARRAY AS THE NEXT ITEM: */
	animationItemArray[animationItemArray.length] = tempAnimationItem;
	
	/** ADD THE ITEM TO THE CANVAS STAGE: **/
	stage.addChild(animationItemArray[animationItemArray.length-1].canvasItem);
	
	/** SET UP THE KeyFrames ON THE ITEM: **/
	/* Create a new keyFrame: */
	tempKeyFrame = new KeyFrame(0, tempCanvasItem.x, tempCanvasItem.y, 0, 0.5, 0.5, "#003D79"); /* new KeyFrame(startTime, x-value, y-value, alpha, scale-x, scale-y) */
	/* Add the KeyFrame to the animationItem's keyFrame Array: */
	tempAnimationItem.keyFrames[tempAnimationItem.keyFrames.length] = tempKeyFrame;
	/* Create a new keyFrame: */
	tempKeyFrame = new KeyFrame(1000, tempCanvasItem.x, tempCanvasItem.y, 1, 1, 1, "#003D79");
	/* Add the KeyFrame to the animationItem's keyFrame Array: */
	tempAnimationItem.keyFrames[tempAnimationItem.keyFrames.length] = tempKeyFrame;
	/* Create a new keyFrame: */
	tempKeyFrame = new KeyFrame(4000, tempCanvasItem.x, tempCanvasItem.y, 1, 1, 1, "#003D79");
	/* Add the KeyFrame to the animationItem's keyFrame Array: */
	tempAnimationItem.keyFrames[tempAnimationItem.keyFrames.length] = tempKeyFrame;
	/* Create a new keyFrame: */
	tempKeyFrame = new KeyFrame(5000, tempCanvasItem.getTransformedBounds().width/2+15, 25, 1, 1, 1, "#D2E0FF");
	/* Add the KeyFrame to the animationItem's keyFrame Array: */
	tempAnimationItem.keyFrames[tempAnimationItem.keyFrames.length] = tempKeyFrame;
	/*** ***/
				
	//console.log("Text color: " + tempCanvasItem.color);
	
	//console.log("Item setup finished");
	
	//console.log(animationItemArray[0].keyFrames[0].startTime);
	//console.log(animationItemArray[0].keyFrames[1].startTime);
	//console.log(animationItemArray[1].keyFrames[0].startTime);
	//console.log(animationItemArray[1].keyFrames[1].startTime);

}

function addJSExample() {
	
	var tempJSItem;
	var tempKeyFrame;
							
	/** CREATE AN JSITEM AND SET THE VALUES: **/
	tempJSItem = new JSItem("testing", "console.log(\"some code to execute\");");
	
	/* ADD THE JSITEM TO THE JSITEM ARRAY AS THE NEXT ITEM: */
	jsItemArray[jsItemArray.length] = tempJSItem;
		
	/** SET UP THE KeyFrames ON THE ITEM: **/
	/* Create a new keyFrame: */
	tempKeyFrame = new jsKeyFrame(2000, 3000, "console.log('key frame code executing....');"); /* new KeyFrame(startTime, endTime, code) */
	/* Add the KeyFrame to the animationItem's keyFrame Array: */
	tempJSItem.keyFrames[tempJSItem.keyFrames.length] = tempKeyFrame;
}

/** ON EACH SLIDE CALL init() FUNCTION: **/
function animationInit() {
	/** CREATE THE STAGE: **/
	stage = new createjs.Stage("mainCanvas");
	
	stage.on("stagemousedown", function(evt) {
		console.log("the canvas was clicked at "+evt.stageX+","+evt.stageY);
	});
	
	/** call the addElements function to add the canvas items/build item array: **/
	//addElements(); /* MOVE TO ANIMATION PAGE? OUTSIDE THIS FUNCTION? */
		
	/** SET UP THE TICK EVENT THAT CALLS THE TICK FUNCTION: **/
	createjs.Ticker.on("tick", animationTickEvent);
	createjs.Ticker.setFPS(15);
}

function resetSlideAnimations(title, displayTime)
{
	/** ON EACH SLIDE LOAD:
	* RESET THE animationItemArray: 
	* RESET THE elapsedTime to 0
	* SET THE TotalTime
	**/
	animationItemArray = [];
	jsItemArray = [];
	elapsedTime = 0;
	totalTime = 0;
	stage.removeAllChildren();
	stage.clear();
	setAnimationPaused(true)
	
	//console.log(displayTime);
	
	if(displayTime !=0 && displayTime != undefined && displayTime != "" && !isNaN(displayTime))
	{
	
		/** LOAD Fade Div: **/
		tempCanvasItem = new createjs.Shape(); 
		tempCanvasItem.x = 0; 
		tempCanvasItem.y = 78; 
		tempCanvasItem.graphics.beginFill("white").drawRoundRectComplex(0, 0, stage.canvas.width, stage.canvas.height-78, 16, 16, 16, 16);
		
		/** CREATE AN ANIMATION ITEM AND ADD THE CANVAS ITEM: **/
		tempAnimationItem = new AnimationItem(tempCanvasItem, tempCanvasItem.x, tempCanvasItem.y, 0.8, 1)
		/* ADD THE ANIMATION ITEM TO THE ITEM ARRAY AS THE NEXT ITEM: */
		animationItemArray[animationItemArray.length] = tempAnimationItem;
			
		/** ADD THE ITEM TO THE CANVAS STAGE: **/
		stage.addChild(animationItemArray[animationItemArray.length-1].canvasItem);
		
		/** SET UP THE KeyFrames ON THE ITEM: **/
		/* Create a new keyFrame: */
		tempKeyFrame = new KeyFrame(2000+displayTime, tempCanvasItem.x, tempCanvasItem.y, 0.8, 1, 1); /* new KeyFrame(startTime, x-value, y-value, alpha, scale-x, scale-y) */
		/* Add the KeyFrame to the animationItem's keyFrame Array: */
		tempAnimationItem.keyFrames[tempAnimationItem.keyFrames.length] = tempKeyFrame;
		/* Create a new keyFrame: */
		tempKeyFrame = new KeyFrame(3000+displayTime, tempCanvasItem.x, tempCanvasItem.y, 0, 1, 1);
		/* Add the KeyFrame to the animationItem's keyFrame Array: */
		tempAnimationItem.keyFrames[tempAnimationItem.keyFrames.length] = tempKeyFrame;
				
		/** LOAD TITLE TEXT INTO CANVAS/KEYFRAMES: **/
		tempCanvasItem = new createjs.Text(title, "bold 40px Arial", "#D2E0FF"); 
		tempCanvasItem.x = stage.canvas.width/2; 
		tempCanvasItem.y = stage.canvas.height/2; 
		tempCanvasItem.textAlign = "center"; 
		tempCanvasItem.textBaseline = "alphabetic";
		tempCanvasItem.alpha = 0;
		
		tempAnimationItem = new AnimationItem(tempCanvasItem, tempCanvasItem.x, tempCanvasItem.y, 0, 5)
		/* ADD THE ANIMATION ITEM TO THE ITEM ARRAY AS THE NEXT ITEM: */
		animationItemArray[animationItemArray.length] = tempAnimationItem;
		
		/** ADD THE ITEM TO THE CANVAS STAGE: **/
		stage.addChild(animationItemArray[animationItemArray.length-1].canvasItem);
		
		/** SET UP THE KeyFrames ON THE ITEM: **/
		/* Create a new keyFrame: */
		tempKeyFrame = new KeyFrame(-1, tempCanvasItem.x, tempCanvasItem.y, 0, 0.5, 0.5, "#003D79"); /* new KeyFrame(startTime, x-value, y-value, alpha, scale-x, scale-y) */
		/* Add the KeyFrame to the animationItem's keyFrame Array: */
		tempAnimationItem.keyFrames[tempAnimationItem.keyFrames.length] = tempKeyFrame;
		/* Create a new keyFrame: */
		tempKeyFrame = new KeyFrame(1000, tempCanvasItem.x, tempCanvasItem.y, 1, 1, 1, "#003D79");
		/* Add the KeyFrame to the animationItem's keyFrame Array: */
		tempAnimationItem.keyFrames[tempAnimationItem.keyFrames.length] = tempKeyFrame;
		/* Create a new keyFrame: */
		tempKeyFrame = new KeyFrame(1000+displayTime, tempCanvasItem.x, tempCanvasItem.y, 1, 1, 1, "#003D79");
		/* Add the KeyFrame to the animationItem's keyFrame Array: */
		tempAnimationItem.keyFrames[tempAnimationItem.keyFrames.length] = tempKeyFrame;
		/* Create a new keyFrame: */
		tempKeyFrame = new KeyFrame(2000+displayTime, tempCanvasItem.getTransformedBounds().width/2+30, 50, 1, 1, 1, "#D2E0FF");
		/* Add the KeyFrame to the animationItem's keyFrame Array: */
		tempAnimationItem.keyFrames[tempAnimationItem.keyFrames.length] = tempKeyFrame;
		
		/** ADD THE JS ANIMATION ITEMS TO SET Z-INDEXES: **/
		/** CREATE AN JSITEM AND SET THE VALUES: **/
		tempJSItem = new JSItem("testing", "console.log(\"some code to execute\");");
		
		/* ADD THE JSITEM TO THE JSITEM ARRAY AS THE NEXT ITEM: */
		jsItemArray[jsItemArray.length] = tempJSItem;
			
		/** SET UP THE KeyFrames ON THE ITEM: **/
		/* Create a new keyFrame to SET Z-INDEX BEFORE THE TITLE ANIMATION: */
		/* tempKeyFrame = new jsKeyFrame(-1, 3000+displayTime, "document.getElementById('mainCanvas').style.zIndex='6000'; document.getElementById('preload').style.visibility = 'hidden'; console.log('js keyframe1...'); console.log(document.getElementById('mainCanvas').style.zIndex);");*/ /* new KeyFrame(startTime, endTime, code) */
		tempKeyFrame = new jsKeyFrame(-1, 3000+displayTime, "document.getElementById('mainCanvas').style.zIndex='6000'; document.getElementById('preload').style.visibility = 'hidden';"); /* new KeyFrame(startTime, endTime, code) */
		/* Add the KeyFrame to the animationItem's keyFrame Array: */
		tempJSItem.keyFrames[tempJSItem.keyFrames.length] = tempKeyFrame;
		/* Create a new keyFrame to SET Z-INDEX AFTER THE TITLE ANIMATION (WILL CHECK FOR 10 mins: */
		/* tempKeyFrame = new jsKeyFrame(3000+displayTime, 600000+displayTime, "document.getElementById('mainCanvas').style.zIndex='4000'; console.log('js keyframe2...'); console.log(document.getElementById('mainCanvas').style.zIndex);"); */ /* new KeyFrame(startTime, endTime, code) */
		tempKeyFrame = new jsKeyFrame(3000+displayTime, 600000+displayTime, "document.getElementById('mainCanvas').style.zIndex='4000'; "); /* new KeyFrame(startTime, endTime, code) */
		/* Add the KeyFrame to the animationItem's keyFrame Array: */
		tempJSItem.keyFrames[tempJSItem.keyFrames.length] = tempKeyFrame;
		
	} else {
		/* NO DISPLAYTIME FOR TITLE - NO ANIMATIONS: */
		/** LOAD TITLE TEXT INTO CANVAS/KEYFRAMES: **/
		tempCanvasItem = new createjs.Text(title, "bold 40px Arial", "#D2E0FF"); 
		tempCanvasItem.x = tempCanvasItem.getTransformedBounds().width/2+30; 
		tempCanvasItem.y = 50; 
		tempCanvasItem.textAlign = "center"; 
		tempCanvasItem.textBaseline = "alphabetic";
		
		tempAnimationItem = new AnimationItem(tempCanvasItem, tempCanvasItem.x, tempCanvasItem.y, 0, 1)
		/* ADD THE ANIMATION ITEM TO THE ITEM ARRAY AS THE NEXT ITEM: */
		animationItemArray[animationItemArray.length] = tempAnimationItem;
		
		/** ADD THE ITEM TO THE CANVAS STAGE: **/
		stage.addChild(animationItemArray[animationItemArray.length-1].canvasItem);
		
		/** SET THE JS TO RESET THE Z-Index? **/
		/** CREATE AN JSITEM AND SET THE VALUES: **/
		tempJSItem = new JSItem("testing", "console.log(\"some code to execute\");");
		
		/* ADD THE JSITEM TO THE JSITEM ARRAY AS THE NEXT ITEM: */
		jsItemArray[jsItemArray.length] = tempJSItem;
			
		/** SET UP THE KeyFrames ON THE ITEM: **/
		/* Create a new keyFrame to SET Z-INDEX (WILL CHECK FOR 10 mins: */
		tempKeyFrame = new jsKeyFrame(-1, 600000, "document.getElementById('mainCanvas').style.zIndex='4000'; document.getElementById('preload').style.visibility = 'hidden'; "); /* new KeyFrame(startTime, endTime, code) */
		/* Add the KeyFrame to the animationItem's keyFrame Array: */
		tempJSItem.keyFrames[tempJSItem.keyFrames.length] = tempKeyFrame;
		
	}
		
}

function setAnimationTotalTime(totalMediaTime)
{
	totalTime = totalMediaTime;
	//console.log("Total Time: " + totalTime);
}

function setAnimationTime(currentMediaTime)
{
	elapsedTime = currentMediaTime;
	//console.log("elapsed Time: " + elapsedTime);
}

function setAnimationPaused(paused)
{
	createjs.Ticker.paused = paused;	
}



