/*************************************
	COMMON FUNCTIONS:
**************************************/

window.addEventListener("load",function() {
	// Set a timeout...
	setTimeout(function(){
		// Hide the address bar!
		window.scrollTo(0, 1);
	}, 0);
	
	
});

/*** WRITE OBJECT PROPERTIES TO CONSOLE FOR TESTING DATA: ***/
function printToConsole(obj) 
{
	"use strict";
	var x;
	/*** WRITE THE DATA TO THE CONSOLE: ***/
	for (x in obj)
	{
		courseMessage(x +": "+obj[x],5);
	}
}

/*** GET URL PARAMETERS: ***/
function getQueryVariable(variable)
{
       var query = window.location.search.substring(1);
       var vars = query.split("&");
	   var i;
       for (i=0;i<vars.length;i++) {
               var pair = vars[i].split("=");
               if(pair[0] == variable){return pair[1];}
       }
       return(false);
}


/*** LOAD XML DOCUMENT: ***/
function loadXMLDoc(filename)
{
	var xmlhttp;
	
	if (window.XMLHttpRequest)
	{
		xmlhttp=new XMLHttpRequest();
	}
	else /*** code for IE5 and IE6 ***/
	{
		xmlhttp=new ActiveXObject("Microsoft.XMLHTTP");
	}

	xmlhttp.open("GET",filename,false);
	xmlhttp.send();

	return xmlhttp.responseXML;
} 

/*** LOAD FILE: ***/
function loadTextFile(filename)
{
	var xhttp;
	
	if (window.XMLHttpRequest)
	{
		xhttp=new XMLHttpRequest();
	}
	else /*** code for IE5 and IE6 ***/
	{
		xhttp=new ActiveXObject("Microsoft.XMLHTTP");
	}
	
	xhttp.open("GET",filename,false);
	xhttp.send();	
	
	return xhttp.responseText;
}

/*** CHECK IF ITEM EXISTS ***/
function fileExists(url) {
	try{
		if(url){
			var req = new XMLHttpRequest();
			req.open('GET', url, false);
			req.send();
			
			return req.status==200;
		} else {
			
			return false;
		}
	} catch(e) {return false;}
}

function loadLink(link,redirectLink) {
	$.ajax({
		url:link,
		type:'HEAD',
		error: function()
		{
			courseMessage("url does not exists, attempting to redirect:" + redirectLink,3)
			if(!(typeof redirectLink === 'undefined' || redirectLink == null)){
				window.open(redirectLink);
			}
		},
		success: function()
		{
			courseMessage("url exists:" + link,3)
			window.open(link);
		}
	});
}

/*** SHOW/HIDE Elements: ***/
function hideSlideBevel()
{
	document.getElementById('slideBevel').style.display = "none";
}

function showSlideBevel()
{
	document.getElementById('slideBevel').style.display = "block";
}

function setNextButtonDisabled(disabled)
{
	nextDisabled = disabled;
}

function setPreviousButtonDisabled(disabled)
{
	prevDisabled = disabled;
}

function hideCourseButtons()
{
	document.getElementById('courseControls').style.display = "none";
}

function showCourseButtons()
{
	document.getElementById('courseControls').style.display = "block";
}

function turnOffHighlights() {
	document.getElementById('highlightMainMenu').setAttribute('class', '');	
	document.getElementById('highlightNavigationControls').setAttribute('class', '');
	document.getElementById('highlightMediaControls').setAttribute('class', '');
	document.getElementById('nextButton').className = 'next';/*removes the flashing CSS animation*/
}

function loadCustomCSS(adminID) {
	var cssId = 'customerCSS';  
	courseMessage('Adding Custom CSS',2,1);
	if (!document.getElementById(cssId))
	{
		var head  = document.getElementsByTagName('head')[0];
		var link  = document.createElement('link');
		link.id   = cssId;
		link.rel  = 'stylesheet';
		link.type = 'text/css';
		link.href = global.courseCutomizationPath+adminID+'/customer.css';
		link.media = 'all';
		head.appendChild(link);
	}	
	courseMessage('Finished Custom CSS',2,0);
}



/****************************************************************

	GLOBAL VARIABLES:

*****************************************************************/

/*** Course Developer Variables ***/

var dev_company_name = "YOW Canada Inc";
var dev_company_phone = "1.866.688.2845";
var dev_company_email = "support@yowcanada.com";
	

var DBValues = new Array(); 	/* Array of Returned Database Values if Tracking = YOW */
var scormDBTrainees = new Array();
var initialFound; 				/* Variable to track if DB/LMS loading was successful */
var user_language = String(getQueryVariable("lang")).toUpperCase(); /* Stores the selected Language - only checks for French when lang=F */

var switch_lang;

/*** CREATE A DATA DICTIONARY TO STORE THE KEY NAME FOR THE DATA MODEL IN DB/SCORM 2004/1.2: ***/


/*** CREATE THE TRAINEE AND COURSE OBJECT VARIABLES: ***/
var course = new Course();
course.loadData();

var default_language = course.default_lang;
var default_switch_language = course.default_switch_lang;

courseMessage("Tracking: "+course.tracking,2);

courseMessage("Default Lang: "+default_language,4);
courseMessage("Default Switch Lang: "+default_switch_language,4);

/*printToConsole(course);*/

var user = new Trainee();
user.loadData(course.chapters);

//Update the title when multiple versions exists in the course_sco.xml(for TDG)
course.updateTitle(user.course_version);

/* NEED TO SET A FORCED LANGUAGE WHEN USING SCORM/NON-ASP DATA: */
courseMessage("FORCED LANG: " + user.forced_language,4 );
if (user.forced_language != "" && user.forced_language !== undefined) {
		courseMessage("setting user lang to forced lang",4);
		user_language = user.forced_language;
}

var chapterArray =[];

var eocQuizObj;

var nextDisabled;
var prevDisabled;
var autoNavCalled;

courseMessage("Course Version: " + user.course_version,2 );


/*** MAIN HTML functions ***/
/* Javascript files are loaded dynamically and will not trigger */
/* onLoad and onUnload from the body tag. use addEventListener instead */
window.addEventListener("load", loadOutline);
window.addEventListener("unload", unloadCourse);



//global for slide reference popup
var slideXml;


/****************************************************************
	CHANGE TEXT TO DIFFERENT LANGUAGE:
	
	Open the XML document. Loop through the Translation Elements.
	Find the Language element text and update the HTML Element with the same ID
	as the Translation Element.
			
	If the Language tag is not found then do not update the HTML element.

******************************************************************/
function change_text_language(file_name, dir_location) {
	courseMessage("Start Change Text Lang",3,1);
	dir_location = dir_location || global.courseFilesPath+"xml/";
	try {
	
		var language = user_language;
		//console.log("loading xml lang: "+dir_location+file_name);
		//console.log(language);
		$.ajax({
			url: dir_location+file_name,
			dataType: "xml",
			success: function(xml) {				
				$(xml).find("translation").each(function(){
					try {
						var id = $(this).attr("id");
						var text = $(this).find(language).text();						
						//console.log("translating item: " +id);
						//console.log("Node: " +$(this).children().first().text());
						if (!text)
						{
							text = $(this).children().first().text();						
						}
						if (!text) {
							text = $(this).text();
						}
						$("." + id).html(text);
						//console.log("translating item: " +id+ " to: "+text);
					} catch (e) {
						courseMessage(e,1);
					}
				});
			}
		});
	
	} catch (e) {
		courseMessage(e,1);
	}
	courseMessage("End Change Text Lang",3,0);
}


/****************************************************************
	LOAD THE OUTLINE PAGE

	This is called anytime the main.html is first called or when 
	'Course Outline' is selected from the main menu.

	Load the outline.html into the main div.
	Create a user object variable and load the data from DB/SCORM
	Load Course data from SCO.
	Populate Fields

******************************************************************/
function loadOutline() {
	courseMessage("Start Load Outline",2,1);
	if (browserCompatibilityTest()){
		courseMessage("Browser is Compatible - Continue",3);
		/*** LOAD THE HTML FILE FOR THE OUTLINE AND PUT IT IN THE mainDIV: ***/
		document.getElementById("mainDiv").innerHTML= loadTextFile(global.courseFilesPath+"outline.html");  
		
		loadCustomCSS(user.adminID);
		
		/*** SET THE AUTONAV STATUS: ***/
		setAutoNavDisplay();
			
		/*** REMOVE THE SWITCH LANG OPTION FROM MENU IF NOT BILINGUAL: ***/
		if (course.multilanguage == "1" || (user.forced_language != "" && user.forced_language !== undefined)) {
			document.getElementById('switchLangDiv').style.display = "none";
			document.getElementById('outlineLangChange').style.display = "none";
		}
		
		if(course.tracking == "1.2" && user.status ==1) {
			doLMSSetValue("cmi.core.lesson_status", "failed");
			doLMSCommit();
		}
		
		setDataValue("language", user_language);
		
		/*** CHECK SCORM DATA: ***/
		//IF SCORM TRACKING:	
		console.log("Tracking: "+course.tracking);
		var scormExpired = false;
		if(course.tracking != "DB") {
			//GET YOW DB SCORM INFO: 
			//CHECK SCORM DATE & NUMBER OF AVAIALBE TRAINEES:
			var today = new Date();
			var scormExpiry = new Date(course.scormExpiry);
			courseMessage("SCORM DATE: " + scormExpiry,2);			
			courseMessage("Available Trainees: "+course.scormTrainees,2);
			
			if(today > scormExpiry || course.scormTrainees < 1) {
				scormExpired = true;
				
			} else {
				scormExpired = false;
			}
		} 
		
		if(course.tracking != "DB" && scormExpired) {	
			courseMessage("SCORM Training Expired",1);
			loadSCORMExpired();
		} else {
			/*** IF USER.STATUS ==1 THEN SHOW LEGAL AGREEMENT: ***/
			if (user.status == 1)
			{		
				loadLegalAgreement();
				
			} else {			
				
				try {
					/* TRY TO CALL THE CUSTOM COURSE OUTLINE CODE */
					course_populateOutline(course, user);
				} catch(e) {
					/* IF FAILS CALL THE BASE POPULATEOUTLINE */
					/*** LOAD THE PAGE CONTENT ONCE THE OUTLINE HAS BEEN LOADED: ***/
					populateOutline(course, user);			
				}			
				
				/*** CONVERT TEXT TO THE SELECTED LANG: ***/
				change_text_language("outline.xml");
			}
		}
	}
	
	
}

/*****************************************************************
	POPULATE OUTLINE:

	Update the Outline Sections with Trainee and Chapter Data:

******************************************************************/
function populateOutline(courseObj, userObj) {

	courseMessage("Start Populating Outline",2,1);

	/*** IF NO USER FOUND SHOW ERROR DIV: ***/
	if(userObj.found == false||userObj.found == null||userObj.found=="false") {
		try{
			document.getElementById("mainDiv").innerHTML = "<div class='mainError'><span class='lUserNotFoundError'>Your user data could not be loaded.</span><br /><span class='lUsername'>Username</span>: "+user.username+"<br /><br /><span class='lErrorContact'>For help Please contact </span>"+dev_company_name+":<br><span class='lPhone'>Phone</span>: "+dev_company_phone+"<br /><span class='lEmail'>email</span>: <a href='mailto:"+dev_company_email+"?subject=Course Help: User not found (Course: "+course.course_abv+" User: "+user.username+")'>"+dev_company_email+"</a></div>";
		} catch(e) {
			courseMessage("There was an error."+e,1);
		}
				
	} 
	else
	{
		try{
			/*** Course Title: ***/
			document.getElementById("CourseTitle").innerHTML = courseObj.title; 
			
			document.title = courseObj.title;
			
			
			
			/*** TITLE SIZE CAN BE PASSED IN THE COURSE_SCO.XML: ***/
			/*document.getElementById('CourseTitle').style.fontSize = "20px;";*/
			
			var audioFile;
			/*** SHOW CLICK ON CHAPTER 1 & Play Audio IF CHAPTER 1 HAS NO SCORE AND LPV =="" ***/
			if (Number(userObj.quizArray[0][0]) == -1) {
				document.getElementById('clickToBegin').style.display = "block";	
				if(getQueryVariable("cbtusername") == "demo_user"){
					document.getElementById('clickToBegin').innerHTML = "<span class='lDemoUser'>Please note: Only module 1 is available for the course demo.</span><button id='playWelcome' class='playWelcome' style='visibility:hidden;'></button>";	
				}
				
				audioFile = "OUTLINE_WELCOME.mp3";	
				
				/*
				LOAD TITLE SCREEN AUDIO:
				*/
				var audio_src = "";
				var fileTypeSplit = audioFile.lastIndexOf("."); 
				if (fileTypeSplit != -1 && user_language!=default_language && course.multilanguage != "1") audioFile = audioFile.substr(0, fileTypeSplit) + "_"+user_language+"."+ audioFile.substr(fileTypeSplit + 1);
				audio_src = "course_specific/all_courses/"+audioFile;
						
				document.getElementById('outlineAudio').innerHTML = "<source id='outlineAudioSource' src='"+audio_src+"' type='audio/mp3'>"
				
				var audioElement = document.getElementById('outlineAudio');
				audioElement.load();
				
				if (/android|ipod|ipad|iphone|tablet|mobile/.test( window.navigator.userAgent.toLowerCase())){
					document.getElementById('playWelcome').style.display = "block";
					document.getElementById('playWelcome').addEventListener('mouseup', function() {
						audioElement.play();		
					}, false);
				}
				else{
					document.getElementById('playWelcome').style.display = "none";
				}
			}
			
			/*** ADD EACH CHAPTER DIV, SET TITLE/SCORE AND DISABLE IF SCORE NOT OVER THRESH: ***/
			var showFinal = true;
			for(var i= 0; i<courseObj.chapters; i++)
			{
				/***
				INSERT A NEW ROW FOR EACH CHAPTER:
				***/
				
				var table = document.getElementById("tocTable");
				var row = table.insertRow(i);
				var cell1 = row.insertCell(0);
				var cell2 = row.insertCell(1);

				/*** ADD THE TEXT TO THE CELLS ***/
				
				cell1.id= "tdChapter"+(i+1);
				cell1.tabIndex = "5";
				cell1.innerHTML = '<div class="chapterAnchor"><div  ><span id="Chapter'+(i+1)+'" >Chapter '+(i+1)+'</span></div><div id="retake'+(i+1)+'" class="retake"><span class="lRetake">Retake Required</span></div></div>';
				cell2.id = "tocScore";
				cell2.className = "tocScore";
				cell2.innerHTML = '<div id="Score'+(i+1)+'" >100%</div>';
				
				
				/*** Chapter Titles: ***/
				document.getElementById("Chapter"+(i+1)).innerHTML= (i+1)+". " + courseObj.chapterTitles[i]; 
					
				if (Number(userObj.quizArray[i][0]) === -1)
				{
					/*** THE CHAPTER HAS NOT BEEN ATTEMPTED - DISPLAY N/A: ***/
					document.getElementById("Score"+(i+1)).innerHTML= "N/A"; 
					
					showFinal = false;
				}
				else
				{
					/*** DISPLAY THE QUIZ SCORE: ***/
					document.getElementById("Score"+(i+1)).innerHTML= userObj.quizArray[i][0]+"%"; 
					
					if(Number(userObj.quizArray[i][0]) >= Number(userObj.quizThresh))
					{
						/*** SET PASSING SCORES TO Green: ***/
						document.getElementById("Score"+(i+1)).style.color = "#70F577";
					}
					else if(Number(userObj.quizArray[i][0]) < Number(userObj.quizThresh))
					{
						/*** The extra IF check on lower than thresh is to make sure the text isnt set to red for non-numeric: ***/
						document.getElementById("Score"+(i+1)).style.color = "#FA8258";
						/*
						document.getElementById("Chapter"+(i+1)).style.color = "#FA8258";
						*/
						showFinal = false;
						document.getElementById("retake"+(i+1)).style.display = "block";
					}
					
				}
				
				/*** ENABLE THE CHAPTER BUTTON IF First Chapter or IF Prev Score > Threshold - Highlight the current chapter: ***/
				var currentChapterSet = false;
				
				if((i === 0 || Number(userObj.quizArray[i-1][0]) >= Number(userObj.quizThresh) || Number(userObj.quizArray[i][0]) >= Number(userObj.quizThresh)))
				{
					if(!currentChapterSet && Number(userObj.quizArray[i][0]) < Number(userObj.quizThresh)) {
						//console.log("setting Current Chapter")
						document.getElementById("tdChapter"+(i+1)).className = "startChapter";
						currentChapterSet = true;
						//document.getElementById("tdChapter"+(i+1)).style.backgroundColor = "#000";
					} else {
						document.getElementById("tdChapter"+(i+1)).className = "chapter";				
					}
					document.getElementById("tdChapter"+(i+1)).setAttribute("onclick", "loadPlayer("+(i+1)+"); return false; ");
				} else {
					//Grey out chapters that are not active.
					document.getElementById("Chapter"+(i+1)).style.color = "#BBBBBB";
				}
			}
			
			/* console.log(show_final); */

			/*** FINAL SCORE: ***/
			if (showFinal)
			{
				var finalScore = 0;
				for(var i= 0; i<courseObj.chapters; i++){
					finalScore = finalScore+(Number(userObj.quizArray[i][0]));
				}
				finalScore = finalScore/courseObj.chapters;
				document.getElementById("FinalScore").innerHTML= Math.round(finalScore)+"%";
			}
			else {
				/*** HIDE THE FINAL SCORE: ***/
				document.getElementById("FinalScore").innerHTML= "N/A";
			}
			
			/*** SET THE TOC HEIGHT: ***/
			var tocHeight = 80+(courseObj.chapters*37)
			document.getElementById("mainTOC").style.height = tocHeight/6+"%";

			/*** USER STATUS DATA: ***/
			/*** IF CERTIFIED SHOW PRINT CERT BUTTON ELSE HIDE IT: ***/
			document.getElementById("Username").innerHTML= userObj.username; 
			document.getElementById("UserFirstLast").innerHTML= userObj.fullName; 
			var progress;
			courseMessage("user status: "+userObj.status,4);
			if (userObj.status == 4 && finalScore >= userObj.quizThresh)
			{
				progress = "Certified";
				document.getElementById("printCert").style.display = "block";
				document.getElementById("leaveFeedback").style.display = "block";
			}
			else
			{
				progress = "In-Progress";
				document.getElementById("printCert").style.display = "none";
				document.getElementById("leaveFeedback").style.display = "none";
				
				/** IF STATUS = 2 & FINAL_SCORE > THRESH THEN CERTIFY: **/
				if(Number(finalScore) >= Number(userObj.quizThresh)) {
					//console.log("Certifying the User!");
					certifyUser();
				}
				else {
					/* RESET COMPLETION/STATUS IF NOT PASSING SCORES: */
					if(courseObj.tracking != "DB") {
						setDataValue("status", "incomplete");	
					
						if(courseObj.tracking == "2004")
						{
							doSetValue("cmi.success_status", "unknown");
							doCommit();			
						};					
					}
				}
			}
			
			try {
				document.getElementById("UserStatus").setAttribute('class', 'lStatus'+progress); 
				document.getElementById("UserStatus").innerHTML = progress; 
				document.getElementById("UserCompany").innerHTML= userObj.company; 			
			} catch(e) {
				
			}
		} catch(e) {
			courseMessage("Cannot load ouline elements: "+e,1);
		}
	}
	
		
	courseMessage("End Populating Outline",2,0);
}

function certifyUser() {
	
	courseMessage("Start Certifying User",2,1);
	
	/** LOAD THE CERTIFY SCEEN **/
	/** replace Dynamic variables **/
	
	var pageText = loadTextFile(global.courseFilesPath+"certify.html"); 
	
	//pageText = pageText.replace(/COURSE_TYPE/g, course.course_abv);
	//console.log(pageText);

	pageText = pageText.replace(/\[\[\!\!COURSE_TYPE\!\!\]\]/g, course.course_abv);
	pageText = pageText.replace(/\[\[\!\!CERT_EMAILS\!\!\]\]/g, user.adminEmail);
	pageText = pageText.replace(/\[\[\!\!CBTUSERNAME\!\!\]\]/g, user.username);
	if (course.tracking == "DB") {
		pageText = pageText.replace(/\[\[\!\!FEEDBACKURL\!\!\]\]/g, "http://www.yowcanada.com/course_feedback.asp");
	}else{
		pageText = pageText.replace(/\[\[\!\!FEEDBACKURL\!\!\]\]/g, "http://www.yowcanada.com/course_feedback_future_course_survey.asp");
    }
	

	/* STOP OUTLINE AUDIO */	
	document.getElementById('outlineAudio').pause();
	
	
	
	document.getElementById("mainDiv").innerHTML =  pageText;
	
	if (course.tracking != "DB") {
		document.getElementById('certEmailed').innerHTML = "<br><br><br>";
	}	
		
	/*** CONVERT TEXT TO THE SELECTED LANG: ***/
	change_text_language("certify.xml");
	
	/*
		REMOVE EMAILED LINE IN SCORM
	*/	
		
	/** SHOW LOADING UNTIL DATA SAVE/CERT CREATION COMPLETE **/
	document.getElementById("cert_loading").style.display = "block";	
	document.getElementById("certifyDiv").style.display = "none";	
		
	/** CERTIFY THE USER: **/
	setCertify();	
	courseMessage("End Certifying User",2,0);
}

function scorm_cert_window(cert_window, cert_attempts) {
	
	courseMessage("Opening cert window - " + cert_attempts,3,1);
	cert_attempts = cert_attempts+1;
	courseMessage('Exp cycle:'+course.expiryCycle,3);
		
	var certdate = user.cert_date;
	var temp_expdate = new Date(certdate);
	temp_expdate.setFullYear(temp_expdate.getFullYear()+parseInt(course.expiryCycle));
	courseMessage('Exp:'+temp_expdate,3);
	
	var expirydate = temp_expdate.getFullYear()+'/'+(temp_expdate.getMonth()+1)+'/'+temp_expdate.getDate();
	
	try{
			courseMessage("SCORM CERT INFO: " + course.scorm_title_english + course.scorm_title_french,4 );
		if (/IE|Trident/.test(navigator.userAgent)){/*if IE*/
			
			cert_window.document.getElementsByClassName("dataCertCourseFrench")[0].innerHTML = course.title; 
			cert_window.document.getElementsByClassName("dataCertCourseEnglish")[0].innerHTML = course.title; 
			cert_window.document.getElementsByClassName("dataName")[0].innerHTML = user.fullName; 
			cert_window.document.getElementsByClassName("dataName")[1].innerHTML = user.fullName; 
			cert_window.document.getElementsByClassName("dataCompany")[0].innerHTML = user.company; 
			cert_window.document.getElementsByClassName("dataCompany")[1].innerHTML = user.company; 
			cert_window.document.getElementsByClassName("dataExpiry")[0].innerHTML = expirydate; 
			cert_window.document.getElementsByClassName("dataExpiry")[1].innerHTML = expirydate; 
			cert_window.document.getElementsByClassName("dataCertDate")[0].innerHTML =  certdate;
			cert_window.document.getElementsByClassName("dataCertDate")[1].innerHTML =  certdate;
		}else{
			cert_window.dataCertCourseEnglish = course.scorm_title_english ;
			cert_window.dataCertCourseFrench = course.scorm_title_french ;			
			cert_window.dataName = user.fullName; 
			cert_window.dataCompany = user.company; 
			cert_window.dataExpiry = expirydate ;
			cert_window.dataCertDate = certdate;
		}
	}catch(err){
		courseMessage(err,1);
		if(cert_attempts < 10){
			setTimeout(function(){scorm_cert_window(cert_window, cert_attempts);} , 1000 );
		}
	}
	courseMessage("Ending cert window",3,0)
}

function openCert() {
		
	if (course.tracking == "DB"){
		/*** IF TACKING IS YOW - OPEN PDF CERTIFICATE: ***/
		window.open("../"+course.course_abv+"/certificates/cert_"+user.username+".pdf" ,'_blank');
	}
	else{
		/*** IF SCORM OPEN CERT OVERLAY: (STANDARD CERT EXCEPT IF TDG THEN TDG CERT) ***/
		var OpenWindow = window.open("course_specific/all_courses/cert.html");
		
		scorm_cert_window(OpenWindow, 0);
	}
}

function openFeedback() {
	if (course.tracking == "DB") {
		window.open("https://www.yowcanada.com/course_feedback.asp?cbtusername=" + user.username, '_blank');
	}
	else {
		window.open("https://www.yowcanada.com/course_feedback_future_course_survey.asp", '_blank');
	}
}
function loadLegalAgreement() {
	
	courseMessage("Start Load Legal Agreement",2,1);
	
	var pageText = loadTextFile(global.courseFilesPath+"legal.html"); 
	document.getElementById("mainDiv").innerHTML=  pageText;	
	
	document.getElementById("MainMenuContent").style.display = "none";
	
	if (course.multilanguage == "1" || (user.forced_language != "" && user.forced_language !== undefined)) {
		document.getElementById('legalChangLang').style.display = "none";
	}
	
	if (course.multilanguage == "1" || (user.forced_language != "" && user.forced_language !== undefined)) {
		document.getElementById('legalChangLang').style.display = "none";		
	}
	
	/*** CONVERT TEXT TO THE SELECTED LANG: ***/
	change_text_language("legal.xml", "course_specific/all_courses/");	
	courseMessage("End Legal",2,0);
}

function loadSCORMExpired() {
	
	courseMessage("Start SCORM PACKAGE EXPIRED SCREEN",2,1);
	
	var pageText = loadTextFile(global.courseFilesPath+"SCORM.html"); 
	
	document.getElementById("mainDiv").innerHTML=  pageText;

	document.getElementById("scorm_expired_name").innerHTML = course.adminName;
	document.getElementById("scorm_expired_email").innerHTML = course.adminEmail;
	document.getElementById("scorm_expired_phone").innerHTML = course.adminPhone;
	
	document.getElementById("MainMenuContent").style.display = "none";
	
	/*** CONVERT TEXT TO THE SELECTED LANG: ***/
	change_text_language("SCORM.xml");	
	
	courseMessage("End SCORM Expired Screen",2,1);
}

function disagree_screen() {
	var pageText = loadTextFile(global.courseFilesPath+"disagree.html"); 
	document.getElementById("mainDiv").innerHTML=  pageText;	
	
	document.getElementById("MainMenuContent").style.display = "none";
	
	/*** CONVERT TEXT TO THE SELECTED LANG: ***/
	change_text_language("legal.xml", "course_specific/all_courses/");		
}

function contactUs() {
	
	courseMessage("Start Loading Contact Us Screen",2,1);
	
	/*** Make Contact Us Div Visible:  ***/
	
	var pageText = loadTextFile(global.courseFilesPath+"contact_us.html"); 
	
	//pageText = pageText.replace(/COURSE_TYPE/g, course.course_abv);
	//console.log(pageText);
	pageText = pageText.replace(/\[\[\!\!dev_company_name\!\!\]\]/g, dev_company_name);
	pageText = pageText.replace(/\[\[\!\!dev_company_phone\!\!\]\]/g,dev_company_phone);
	pageText = pageText.replace(/\[\[\!\!dev_company_email\!\!\]\]/g,dev_company_email);
	pageText = pageText.replace(/\[\[\!\!dev_company_email_link\!\!\]\]/g,dev_company_email+"?subject=Course Help: (Course: "+course.course_abv+" User: "+user.username+")");
	
	pageText = pageText.replace(/\[\[\!\!USERNAME\!\!\]\]/g,user.username);	
	
	var progress;
	if (user.status == 4)
	{
		progress = "Certified";
	}
	else
	{
		progress = "In-Progress";
	}
	pageText = pageText.replace(/\[\[\!\!STATUS\!\!\]\]/g,progress);	
	
	var browser = get_browser_info();
	
	pageText = pageText.replace(/\[\[\!\!BROWSER_VERSION\!\!\]\]/g,browser.name+" "+browser.version);	
	pageText = pageText.replace(/\[\[\!\!COURSE_URL\!\!\]\]/g,location.href);	
	
	document.getElementById("mainDiv").innerHTML=  pageText;
	
	/*
		LOAD CONTACT AUDIO:
	*/
	var audio_src = "";
	var audioFile = "CONTACT_US.mp3";
	var fileTypeSplit = audioFile.lastIndexOf("."); 
	if (fileTypeSplit != -1 && user_language!=default_language && course.multilanguage != "1") audioFile = audioFile.substr(0, fileTypeSplit) + "_"+user_language+"."+ audioFile.substr(fileTypeSplit + 1);
	audio_src = global.courseFilesPath+"audio/"+audioFile;
	
	
	document.getElementById('contactAudio').innerHTML = "<source id='contactAudioSource' src='"+audio_src+"' type='audio/mp3'>"
	
	var audioElement = document.getElementById('contactAudio');
	audioElement.load();
	
	/*** CONVERT TEXT TO THE SELECTED LANG: ***/
	change_text_language("contact.xml");	
	
	document.getElementById("backToMain").focus();	

	courseMessage("End Contact Us",2,0);	
}

function demo_complete() {
	courseMessage("Start Loading Demo Complete Screen",2,1);
	
	/*** Make Contact Us Div Visible:  ***/
	
	var pageText = loadTextFile(global.courseFilesPath+"demo_complete.html"); 
	
	//pageText = pageText.replace(/COURSE_TYPE/g, course.course_abv);
	//console.log(pageText);
		
	document.getElementById("mainDiv").innerHTML=  pageText;
			
	/*** CONVERT TEXT TO THE SELECTED LANG: ***/
	change_text_language("demo.xml");	
	
	document.getElementById("backToMain").focus();		
	courseMessage("End Demo Complete Screen",2,0);
}

function closeLPV() {
	document.getElementById("mainOverlay").style.display = "none";
	document.getElementById("lpvPopup").style.display = "none";
}

function glossaryNav(event, letter){
	if(event.keyCode == 13 || event.button == 0){
		location.href = "#"+letter; //redirects to id of letter
		document.getElementById(letter).nextSibling.focus();
		courseMessage("This class: " +document.activeElement.innerHTML,4);
		while(document.activeElement.className != "dicListWord"){
			document.activeElement.nextSibling.focus();	
		};
	}
}
function loadGlossary() {
	
	courseMessage("Start Loading Glossary",2,1);
	
	document.getElementById("mainOverlay").style.display = "block";
	document.getElementById("glossaryWrapper").style.display = "block"; 
	document.getElementById("glossaryPopUp").style.display = "block";
	document.getElementById("dictionaryDefinition").style.display = "block";
	document.getElementById("dictionaryList").style.height = "35%";
	document.getElementsByClassName("glossaryTitle")[0].innerHTML = 'Glossary';
		
	try{
		if(document.getElementById('media-audio').currentTime > 0){
			document.getElementById('media-audio').pause();
		}
	}catch(err){
		courseMessage(err,1);
	}
	
	var arrayGlossary = [];
	var arrayDictionary = [];
	var possition = 0;
	
	var glossaryFile = "glossary.xml";
	var fileTypeSplit = glossaryFile.lastIndexOf("."); 
	if (fileTypeSplit != -1 && user_language!=default_language && course.multilanguage != "1") glossaryFile = glossaryFile.substr(0, fileTypeSplit) + "_"+user_language+"."+ glossaryFile.substr(fileTypeSplit + 1);
				
	var xml = loadXMLDoc("course_specific/all_courses/"+glossaryFile);
	
	var letterNode = xml.getElementsByTagName("letter");
	
	for( var i = 0 ; i< letterNode.length; i++){
		var letter = xml.getElementsByTagName("letter")[i].getAttribute("text");
		document.getElementById("dictionaryList").innerHTML += "<p id='"+letter+"'  class='dicListLetter' style='cursor:default;' tabindex='3' ><a>"+ letter +"</a></p>";
		document.getElementById("glossaryAlpha").innerHTML += "<span><a  tabindex='2' onmouseup='glossaryNav(event, \""+letter+"\");'  onkeyup=' glossaryNav(event, \""+letter+"\"); '  >"+letter + "&nbsp;&nbsp;</a></span>";
		
		var termNodeList = xml.getElementsByTagName("letter")[i].getElementsByTagName("term");
				
		for( j = 0 ; j< termNodeList.length; j++){
			/*
			document.getElementById("dictionaryList").innerHTML +=  "<h3 id='something' style='cursor:pointer;' onclick='getDefinition("+i+","+j+","+xml+")'>"+  xml.getElementsByTagName("letter")[i].getElementsByTagName("term")[j].getAttribute("text") + "</h3>";
			*/
			
			//console.log("Term: "+ xml.getElementsByTagName("letter")[i].getElementsByTagName("term")[j].childNodes[0].nodeValue);
			
			arrayDictionary[possition]= xml.getElementsByTagName("letter")[i].getElementsByTagName("term")[j].childNodes[0].nodeValue;
			document.getElementById("dictionaryList").innerHTML +=  "<p termPosition='"+possition+"' class='dicListWord' style='cursor:pointer;' tabindex='3'>"+ arrayDictionary[possition] + "</p>";
			
			/*** SET ONCLICK ON WORD TO LOAD DEFINITION ***/
			document.getElementById("dictionaryList").addEventListener("click", getDefinition);
			
			possition++;		
		}
		
	} 
	
	document.getElementById("glossaryPopUp").focus();
	courseMessage("End Load Glossary",2,0);
}

function getDefinition(ev){
	
	courseMessage("Glossary-Getting Definition",3,1);
	
	var glossaryFile = "glossary.xml";
	var fileTypeSplit = glossaryFile.lastIndexOf("."); 
	if (fileTypeSplit != -1 && user_language!=default_language && course.multilanguage != "1") glossaryFile = glossaryFile.substr(0, fileTypeSplit) + "_"+user_language+"."+ glossaryFile.substr(fileTypeSplit + 1);
				
	var xml = loadXMLDoc("course_specific/all_courses/"+glossaryFile);
	/*
	console.log("lod work?");
	console.log("lod work?");
	*/
	var word = ev.target.innerHTML;
	/*
	document.getElementById("dictionaryDefinition").innerHTML += "<h3>"+  xml.getElementsByTagName("letter")[i].getElementsByTagName("term")[j].getElementsByTagName("definition")[0].childNodes[0].nodeValue + "</h3>";
	*/
	//for(i = 0; i < xml.getElementsByTagName("term").length; i++){
		console.log("termPostition: "+ev.target.getAttribute("termPosition"));
		if(ev.target.innerHTML == xml.getElementsByTagName("term")[ev.target.getAttribute("termPosition")].childNodes[0].nodeValue){			document.getElementById("dictionaryDefinition").innerHTML = "<p class='dicWord'>"+  ev.target.innerHTML + "</p>";
			document.getElementById("dictionaryDefinition").innerHTML += "<p class='dicWordDeff'>"+  xml.getElementsByTagName("definition")[ev.target.getAttribute("termPosition")].childNodes[0].nodeValue + "</p>";
		}
	//}
	courseMessage("Glossary - End Definition",3,0)
}

function closeGlossary(){
	document.getElementById("dictionaryList").innerHTML = "";
	document.getElementById("glossaryAlpha").innerHTML = "";
	document.getElementById("dictionaryDefinition").innerHTML = "";
	document.getElementById("mainOverlay").style.display = "none";
	document.getElementById("glossaryWrapper").style.display = "none";
	document.getElementById("glossaryPopUp").style.display = "none";
	try{
		if(document.getElementById('media-audio').currentTime > 0){
			document.getElementById('media-audio').play();
		}
	}catch(err){
		courseMessage(err,1);
	}
}

function loadIndex(chapNum) {
	
	courseMessage("Start Loading Index (Chapter SCO?)",2,1);
	
	document.getElementById("mainOverlay").style.display = "block";
	document.getElementById("glossaryWrapper").style.display = "block"; 
	document.getElementById("glossaryPopUp").style.display = "block";
	document.getElementById("dictionaryDefinition").style.display = "none";
	
	document.getElementById("dictionaryList").style.height = "80%";
	document.getElementsByClassName("glossaryTitle")[0].innerHTML = "INDEX";
	try{
		if(document.getElementById('mediaAudio').currentTime > 0){
			document.getElementById('mediaAudio').pause();
		}
	}catch(err){
		courseMessage(err,1);
	}
	

	for( var i = 0 ; i< chapterArray.length; i++){
		if(chapterArray[i][2] == 0){
			if (xmlDoc == null){
				var xmlDoc;
			}
			xmlDoc=loadXMLDoc("chapter"+chapNum+"_sco.xml");
			var x = chapterArray[i][1];
		}
		else{
			if (xmlDoc == null){
				var xmlDoc;
			}
			xmlDoc=loadXMLDoc("../../../course_account_customisation/"+user.adminID+"/"+course.course_abv_english+"/chapter"+chapNum+"_sco.xml");
			var x = chapterArray[i][1];
		}
		
		var pageTitle = xmlDoc.getElementsByTagName("page")[x].getElementsByTagName("title")[0].getElementsByTagName(user_language)[0].childNodes[0].nodeValue;	
		document.getElementById("dictionaryList").innerHTML += 
		"<p class='dicListLetter' style='cursor:pointer;'> \
		<a onclick='closeGlossary();loadSlide("+chapNum+","+i+");'>"+
		(i+1) +":  "+ chapterArray[i][0]+" : "+
		pageTitle+"</a></p>";
		
	} 
	courseMessage("End Loading Index",2,0)	
}

function showSlideDetails(slideChapter, slidePos, slideXmlNode) {
	var messageString = "";
	
	messageString = messageString+"Chapter: "+slideChapter+"\n";		
	messageString = messageString+"Position: "+(parseInt(slidePos)+1)+" of "+chapterArray.length+"\n";
	
	try {
		messageString = messageString+"Slide ID: "+slideXmlNode.getAttribute("id")+"\n";
	} catch (e) {
		messageString = messageString+"Slide ID not found\n";
	}
	try {
		messageString = messageString+"File To Load: "+slideXmlNode.getElementsByTagName("slide")[0].childNodes[0].nodeValue+"\n";
	} catch (e) {
		messageString = messageString+"File To Load not found\n";
	}
	try {
		messageString = messageString+"Audio To Load: "+slideXmlNode.getElementsByTagName("audio")[0].childNodes[0].nodeValue+"\n";
	} catch (e) {
		messageString = messageString+"Audio To Load not found\n";
	}
	
	alert(messageString);
	
}

function toggleFullScreen() {
	/*Fullscreen only for mobile users*/
	/*FullScreen will not yet work on apple products as they use iOSsafari and iOSsafari does not have fullscreen.*/
	var android = /android/.test( window.navigator.userAgent.toLowerCase() );	
	var doc = window.document;
	var docEl = doc.documentElement;
	var requestFullScreen = docEl.requestFullscreen || docEl.mozRequestFullScreen || docEl.webkitRequestFullScreen || docEl.msRequestFullscreen;
	var cancelFullScreen = doc.exitFullscreen || doc.mozCancelFullScreen || doc.webkitExitFullscreen || doc.msExitFullscreen;

	if(android && !doc.fullscreenElement && !doc.mozFullScreenElement && !doc.webkitFullscreenElement && !doc.msFullscreenElement) {
		requestFullScreen.call(docEl);
	}
	else if(android) {
		cancelFullScreen.call(doc);
	}
  
}


function unloadCourse() {
	/*alert("The Window is unloading");*/
	//user.quizArray[0][0] = 94;
	/*console.log("attempts: " +user.quizArray[eocQuizObj.eocChapter-1][1]);*/
	//user.quizArray[0][1] = 1;		
	//setQuizValue(1, user.quizArray[0][0], user.quizArray[0][1], 1);
	setDataValue("exit", "suspend");
}

/****************************************************************
	FUNCTION TO CHECK USER'S BROWSER AND IF NOT SUPPORTED SHOW 
	AN ERROR MESSAGE AND NOT LOAD COURSE
******************************************************************/
function browserCompatibilityTest(){
	var errString = "";

	browser={};
	if(/android|ipod|ipad|iphone|tablet|mobile/.test( window.navigator.userAgent.toLowerCase())){
		if(!(/crios|version|chrome/.test(window.navigator.userAgent.toLowerCase())) || (/opr|opios|u;/.test(window.navigator.userAgent.toLowerCase()))){
			//crios = chrome IOS
			//version is used for safari? (many bowers use safari in their userAgent so use version as safari test)
			//opr||opios = opera, opera does not like our site on mobile, so advice user not to use. Opera's userAgent contains chrome/safari/firefox, so must check individually.			
			//u; = dolphin browser
			alert("We advise you to use Google Chrome or Safari to view this course as some of the course components may not function properly.");	
		}		
	}
	else if (/(MSIE\ [0-9]{1})/i.test(navigator.userAgent)) {
		browser.agent = navigator.userAgent.match(/(MSIE\ [0-9]{1})/i)[0].split(" ")[0];
		browser.version  = parseInt(navigator.userAgent.match(/(MSIE\ [0-9]{1})/i)[0].split(" ")[1]);
		if (browser.version <= 10 && browser.version != 1){
			errString = "<a href='http://windows.microsoft.com/en-CA/internet-explorer/download-ie'>Internet Explorer</a>";
		}
	}
	else if (/(firefox\/[0-9]{3})/i.test(navigator.userAgent)) {
		browser.agent = navigator.userAgent.match(/(firefox\/[0-9]{3})/i)[0].split("/")[0];
		browser.version  = parseInt(navigator.userAgent.match(/(firefox\/[0-9]{3})/i)[0].split("/")[1]);
		if (browser.version <= 20 && browser.version != 1){
			errString = "<a href='https://www.mozilla.org/en-US/firefox/new/'>Firefox</a>";
		}
	}
	else if (/(opr\/[0-9]{3})/i.test(navigator.userAgent)) {
		browser.agent = navigator.userAgent.match(/(opr\/[0-9]{3})/i)[0].split("/")[0];
		browser.version  = parseInt(navigator.userAgent.match(/(opr\/[0-9]{3})/i)[0].split("/")[1]);
		if (browser.version <= 24 && browser.version != 1){
			errString = "<a href='http://www.opera.com'>Opera</a>";
		}
	}
	if (errString != ""){
		document.getElementById("mainDiv").innerHTML = "<div class='mainError'><span class='lUserNotFoundError'>The version of your browser is not supported.<br> Please download and install the latest version of "+errString+"</span><br /><br /><span class='lErrorContact'>For help please contact </span>"+dev_company_name+":<br><span class='lPhone'>Phone</span>: "+dev_company_phone+"<br /><span class='lEmail'>email</span>: <a href='mailto:"+dev_company_email+"?subject=Course Help: Browser Support (Course: "+course.course_abv+" User: "+user.username+")'>"+dev_company_email+"</a></div>";
		return false;
	}
	else{
		return true;
	}
}

/*************************************************************
	MAIN PLAYER FUNCTIONS:
**************************************************************/

function loadPlayer(chapNum) {
	try {
		/* TRY TO CALL THE CUSTOM COURSE OUTLINE CODE */
		loadPlayer_course(chapNum);
	} catch(e) {
		courseMessage("error loading course player: " +e,1);
		/* IF FAILS CALL THE BASE POPULATEOUTLINE */
		/*** LOAD THE PAGE CONTENT ONCE THE OUTLINE HAS BEEN LOADED: ***/
		loadPlayer_core(chapNum);			
	}			
}

function loadPlayer_core(chapNum) {
	courseMessage("Start Loading Module Player",2,1);

	/*** LOAD THE PLAYER ELEMENTS FROM HTML FILE: ***/
	document.getElementById("mainDiv").innerHTML=loadTextFile(global.courseFilesPath+"player.html");  
			
	/*** Initialize the Media Player Elements: ***/
	initialiseMediaPlayer();
	
	/*** REPLACE MAIN TITLES: ***/
	document.getElementById('courseTitle').innerHTML = course.title; 
	
	document.getElementById('chapterTitle').innerHTML = course.chapterTitles[chapNum-1];
	document.getElementById('chapterTitle').setAttribute("chapter", chapNum);
	/*** SET CHAPTER NUMBER IN PROGRESS WINDOW: ***/
	document.getElementById('chapNum').innerHTML = chapNum;
	
	/*** ADD CLICK EVEN FOR YOWTEST ACCOUNTS: ***/
	if((user.company).toUpperCase() == "YOW TEST"){
		document.getElementsByClassName('slideLOGO')[0].onclick = function(){loadIndex(chapNum);};
		document.getElementsByClassName('slideLOGO')[0].style.cursor = 'pointer';
		
		//document.getElementById('playerProgress').onclick = function(){showSlideDetails();};
		//document.getElementById('playerProgress').style.cursor = 'pointer';
	}
	/*** Set the canvas animation item: ***/
	animationInit();
	
	/*** CONVERT TEXT TO THE SELECTED LANG: ***/
	change_text_language("player.xml");
	
	setChapterArray(chapNum);
	getLastPageViewed(chapNum);
	courseMessage("End Loading Module Player",2,0);
}

function setChapterArray(chapNum){
	//loops throught chapter, creating a dictionary of every page that matches the users version and class spesifications
	

	courseMessage("Start Building Chapter Page Array",2,1)
	/*** OPEN CHAPTER XML:	***/
	/****************************************************************************
		READ XML FILE
	*****************************************************************************/
	try{
		/*** try to read XML file ***/
		if (xmlDoc == null){
			var xmlDoc;
		}
		xmlDoc=loadXMLDoc("chapter"+chapNum+"_sco.xml");
    
	}
	catch(err){
		courseMessage("Error Opening Chapter SCO: "+err,1);
	}
	

	/*** OPEN CUTOMER CUSTOMISE XML:	***/
	/****************************************************************************
		READ XML FILE
	*****************************************************************************/
	try{
		/*** try to read XML file ***/
		if (xmlDocCust == null){
			var xmlDocCust;
		}
		xmlDocCust=loadXMLDoc(global.courseCutomizationPath+user.adminID+"/"+course.course_abv_english+"/chapter"+chapNum+"_sco.xml");
		courseMessage("xmlDocCust - found customize sco files",3);
	}
	catch(err){
		courseMessage("No customize SCO files: "+err,1);
	}
	
	//console.log("account_customisation/"+user.adminID+"/"+course.course_abv_english+"/chapter"+chapNum+"_sco.xml");
	
	
	
    try{
		//chapterArray =[[]];
		
		for(i=0; i < xmlDoc.getElementsByTagName("page").length; i++){
			//CHECK FOR COURSE SPECIFIC CONDITIONS:
			var course_specific_conditions = true;
			try{
				course_specific_conditions = check_course_page_conditions(xmlDoc.getElementsByTagName("page")[i]);
			}catch(e){
				courseMessage("There was an error during course specific page check (or function does not exist)",1);				
			}
			
			//BMC:
			//potentially want to split the page.version attribute into array and check to see if user.version matches any of the versions in the array (array_var.includes("value_str");:
			//Also - can be written as: If page.version == null || or user.version == page.version[array check] then push.  and remove the else if.
			var page_version = xmlDoc.getElementsByTagName("page")[i].getAttribute("version");
			var course_version_array = null;
			if (page_version!==null) {
				course_version_array= page_version.split(",");
			}
			if( ( course_version_array !== null && (course_version_array.includes(user.course_version.toString())) && course_specific_conditions) )
			{
				chapterArray.push([xmlDoc.getElementsByTagName("page")[i].getAttribute("id"), i, 0]);
				//.push is used to add items to an array
				//console.log("ADDED PAGE" + xmlDoc.getElementsByTagName("page")[i].getAttribute("id"))
			}
			else if(course_version_array == null && course_specific_conditions ){
				chapterArray.push([xmlDoc.getElementsByTagName("page")[i].getAttribute("id"), i, 0]);

				//.push is used to add items to an array
				//console.log("ADDED PAGE" + xmlDoc.getElementsByTagName("page")[i].getAttribute("id"))
			}
		}
		//if customize course pages - add them at the end of the course
		if (xmlDocCust != null || xmlDocCust != ""){
			for(i=0; i < xmlDocCust.getElementsByTagName("page").length; i++){
				var course_specific_conditions = true;
				try{
					course_specific_conditions = check_course_page_conditions(xmlDoc.getElementsByTagName("page")[i]);
				}catch(e){
					courseMessage("There was an error during course specific page check (or function does not exist)",1);				
				}
				console.log("Course Page Cond: "+course_specific_conditions);
				//BMC:
				//potentially want to split the page.version attribute into array and check to see if user.version matches any of the versions in the array (array_var.includes("value_str");:
				//Also - can be written as: If page.version == null || or user.version == page.version[array check] then push.  and remove the else if.			
				var cust_version = xmlDocCust.getElementsByTagName("page")[i].getAttribute("version");
				var cust_version_array = null;
				if (cust_version!==null) {
					cust_version_array= cust_version.split(",");
				}
				if( ( cust_version_array !== null && (cust_version_array.includes(user.course_version.toString()))&& course_specific_conditions) )
				{
					chapterArray.splice(chapterArray.length-1, 0, [xmlDocCust.getElementsByTagName("page")[i].getAttribute("id"), i, 1]);

				}
				else if(cust_version_array == null && course_specific_conditions){
					chapterArray.splice(chapterArray.length-1, 0, [xmlDocCust.getElementsByTagName("page")[i].getAttribute("id"), i, 1]);

				}
			}
			
		}
	}catch(err){
		courseMessage("ERROR During Page Build: "+err,1);
	}
	
	/*USED TO SHOW ITEMS IN DICTIONARY*/
	//for ( i=0; i<chapterArray.length; i++ )
	//{
	//	for ( j=0; j<chapterArray[i].length; j++ )
	//	{
	//		//console.log("i: "+i+"j "+j+"chapterarayy "+chapterArray[i][j]);
	//		
	//	}
	//}
}
function getLastPageViewed(chapNum){
	//if user has a last page viewed, check to see if ID of LPV is in chapterArray[if its not, the user should not be on that page as they do not match version or code] and set the completeDictPosition accordingly

	
	
	/*** GET THE LAST CHAPTER VIEWED ***/
	var lcv = user.lpv.split("_");
	var chapterArrayPoss = 0;
	lcv = lcv[0];
	lcv = lcv.replace("M", "");
	
	courseMessage("Last Chapter Viewed: " + lcv+ " | Last User Page Viewed: "+user.lpv,3);
	//loop throught chapterArray seeing if userLPV is in dict | TRUE set Dict position | False Load first page
	if (user.lpv != "" && user.lpv != undefined &&user.lpv != null && lcv == chapNum) {
		var i=0;
		while(i<chapterArray.length){
			if (user.lpv == chapterArray[i][0]){
				chapterArrayPoss = i;
				break;
			}
			else {
				i++;
			}
		}
	}
	
	
	if (user.lpv != "" && user.lpv != undefined &&user.lpv != null && lcv == chapNum && chapterArrayPoss != 0) {
		/*** IF FOUND SHOW LPV SCREEN: ***/
		document.getElementById("mainOverlay").style.display = "block";
		document.getElementById("lpvPopup").style.display = "block";
		
		/*** SET THE YES BUTTON TO LOAD THE SLIDE FOR LAST PAGE VIEWED: ***/
		document.getElementById("lpvYES").onclick = function() { 
			closeLPV(); 
			loadSlide(chapNum, chapterArrayPoss); 
			return false; 
		};
		/*** NO SET chapterArrayPoss to 0 AND LOADS THE DEFAULT PAGE - PAGE 1: ***/
		document.getElementById("lpvNO").onclick = function() { 
			setDataValue("lpv", 0); 
			closeLPV(); 
			loadSlide(chapNum, 0); 
			return false; 
		};
	}	
	else {	
		/*** ELSE SHOW FIRST SLIDE:	***/
		loadSlide(chapNum, 0);
	}
}
function loadSlide(chapNum, chapterArrayPoss) {
	/* DISPLAY MEDIA CONTROLS - THEY MAY BE HIDDEN */
	document.getElementById("mediaPlayer").style.display = "block";
	document.getElementById("progressBar").style.display = "block";
	
	try {
		/* TRY TO CALL THE CUSTOM COURSE OUTLINE CODE */
		
		course_loadSlide(chapNum, chapterArrayPoss);
	} catch(e) {
		/* IF FAILS CALL THE BASE POPULATEOUTLINE */
		/*** LOAD THE PAGE CONTENT ONCE THE OUTLINE HAS BEEN LOADED: ***/
		main_loadSlide(chapNum, chapterArrayPoss);			
	}
	
	
}

function main_loadSlide(chapNum, chapterArrayPoss) {
	courseMessage("Start Load Slide [chapNum : "+chapNum+" chapterArrayPoss: "+chapterArrayPoss&"]",2,1);
	//console.log("** Loading Slide: "+chapterArray[chapterArrayPoss+1][0]+" **");
	removeAnimControls();	//to remove the eventList for swiffy - in /meida_player.js
	/*
	console.log("Loading Page: " + pageId );
	console.log("Chapter: " + chapNum );
	*/
	autoNavCalled = false;
	
	turnOffHighlights();
	
	/*** START LOADING SCREEN ***/
	resetPreload();	

	
	
	var pageNode;
	var assetURL = "";



	/************************************************************
	CHECK TO SEE IF NOT A CLIENT CUSTOME PAGE OR YES
	/***********************************************************/

		if(chapterArray[chapterArrayPoss][2] == 0){	
			/*** OPEN CHAPTER XML:	***/
			/****************************************************************************
				READ XML FILE
			*****************************************************************************/
			try{
				/*** try to read XML file ***/
				if (xmlDoc == null){
					var xmlDoc;
				}
				xmlDoc=loadXMLDoc("chapter"+chapNum+"_sco.xml");

			}
			catch(err){
				courseMessage(err,1);
			}
			
			//var x = customDict.indexOf(pageid);
			pageNode = chapterArray[chapterArrayPoss][1];
		}
		else{	
			//************************************************************
			//lucas code to get id of custome page
			//var x = customDict.indexOf(pageid.replace("CUST_",""));
			//************************************************************
			
				
			/*** OPEN CHAPTER XML:	***/
			/****************************************************************************
				READ XML FILE
			*****************************************************************************/
			
			try{
				/*** try to read XML file ***/
				if (xmlDoc == null){
					var xmlDoc;
				}
				xmlDoc=loadXMLDoc(global.courseCutomizationPath+user.adminID+"/"+course.course_abv_english+"/chapter"+chapNum+"_sco.xml");
				pageNode =  chapterArray[chapterArrayPoss][1];
				assetURL = global.courseCutomizationPath+user.adminID+"/"+course.course_abv_english+"/";
			}
			catch(err){
				courseMessage(err,1);
			}

				
		}



	//***********************************************************************
	// setup global xml to get our chapter course SCO data 
	// use this as an alertnative to using xmlDoc all the time
	// (works with the NewMediaPlayer class in sub_controls.js)
	//***********************************************************************
	slideXml = new SlideXml();
	slideXml.openXmlSco(chapNum, chapterArray, chapterArrayPoss);



	/*** LOAD TESTING DATA FOR YOW USERS: ***/
	if((user.company).toUpperCase() == "YOW TEST"){
				
		document.getElementById('playerProgress').onclick = function(){showSlideDetails(chapNum, chapterArrayPoss,xmlDoc.getElementsByTagName("page")[pageNode]);};
		document.getElementById('playerProgress').style.cursor = 'pointer';
	}

	courseMessage("url: "+assetURL,4);
	courseMessage("course Abv: "+course.course_abv,4);
	courseMessage("course Abv ENGLISH: "+course.course_abv_english,4);
		
	courseMessage("pageNode: "+pageNode,4);
	/*
	TODO:
	IF PAGE NOT FOUND SHOW ERROR?
	*/
	
	var titleDisplayTime = parseInt(xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("title")[0].getAttribute("displayTime"));
	var slideTitle; // = xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("title")[0].childNodes[0].nodeValue;
	if (xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("title")[0].getElementsByTagName(user_language)[0] !== undefined) {
		slideTitle = xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("title")[0].getElementsByTagName(user_language)[0].childNodes[0].nodeValue;
	} else {
		if(xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("title")[0].getElementsByTagName(default_language)[0] !== undefined)
		{
			slideTitle = xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("title")[0].getElementsByTagName(default_language)[0].childNodes[0].nodeValue;		
		} else {
			slideTitle = xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("title")[0].childNodes[0].nodeValue;		
		}				
	}
		
	//CHECK TO SEE IF TITLE LENGTH > X
	var imageElement = document.getElementById("companyLogoImg");
	courseMessage("Img Width: "+imageElement.style.width,5);
	courseMessage("Title Length: "+slideTitle.length,5);
		
	imageElement.style.width = "100%";
	imageElement.style.height = "100%";
	imageElement.style.WebkitTransitionDelay = "0s";
	imageElement.style.transitionDelay = "0s";
	courseMessage("Img Width: "+imageElement.style.width,5);
		
	if (slideTitle.length > 47)
	{
		imageElement.style.width = "60%";
		imageElement.style.height = "60%";
		imageElement.style.WebkitTransitionDelay = "3s";
		imageElement.style.transitionDelay = "3s";
	}
	courseMessage("Img Width: "+imageElement.style.width,5);
	courseMessage("Title Length: "+slideTitle.length,5);
		
	//console.log("slide: "+slideTitle);
		
	/*** LOAD PAGE_NODE Data Into Page Elements: ***/
	if ("eoc" === xmlDoc.getElementsByTagName("page")[pageNode].getAttribute("type")){
		titleDisplayTime = 0;
		//document.getElementById('preload').style.visibility = "hidden";
		hideCourseButtons();
		
		
		/*********************************************************
			EOC
		**********************************************************/
		
		setPreviousButtonDisabled(true);
		setNextButtonDisabled(true);
		
		/*** HIDE PAGE ELEMENTS: ***/
		document.getElementById('narrationWindow').style.display = "none";
		document.getElementById('playerProgress').style.display = "none";
		document.getElementById('navigationDiv').style.display = "none";
		document.getElementById("MainMenuContent").style.display = "none";
		hideSlideBevel();		
		document.getElementById('mediaPlayer').style.display = "none";
						
		/*** LOAD THE PAGE TITLE, DIVS, AND AUDIO: ***/
		/** ON EACH SLIDE LOAD: ***/
		/* GET THE DISPLAY TIME: */
		
	
		/*** RESET ANIMATIONS AND SET SLIDE TITLE ANIMATION: ***/
		resetSlideAnimations(slideTitle, titleDisplayTime);
		
		/*** GET THE NUMBER OF QUESTIONS TO ASK: ***/
		var questions_to_ask = xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("slide")[0].childNodes[0].nodeValue;
			
		/*** Show the fancy slide bevel div ***/
		/*showSlideBevel();*/
	
		/*** LOAD THE STANDARD ELEMENTS - Title, Narration, Audio: ***/
		/*
		document.getElementById('slideTitle').innerHTML = xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("title")[0].childNodes[0].nodeValue;
		*/
		document.getElementById('slideTitle').innerHTML = "";
		
		//document.getElementById('slideTitle').innerHTML = xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("title")[0].childNodes[0].nodeValue;
		document.getElementById('slideWindow').className = "EOCInstructionsWindow";
		
		/*** SET THE Z-INDEX FOR THE STAGE ***/
		document.getElementById('slideWindow').style.zIndex='5000';
		
		/*
		TRANSLATE
		*/
		document.getElementById('slideWindow').innerHTML = "<h1 style='text-align:center;'><span class='lEOCTitle'>End of Module Quiz</span> <span id='eocChapNum'>"+chapNum+"</span></h1>";
		
		/*** CHECK TO SEE IF USER HAS ALREADY PASSED THIS CHAPTER QUIZ - IF SO DONT ALLOW THEM TO TAKE THE QUIZ ***/
		/* 
		console.log("Quiz Score: " + user.quizArray[chapNum-1][0]);
		console.log("Quiz Thresh: " + user.quizThresh);
		*/
		if (user.status == 4)
		{
			/*
			TRANSLATE
			*/
			document.getElementById('slideWindow').innerHTML += "<p><span class='lEOCCert1'>Because you have already certified for this course you will be unable to take the quiz again</span>.</p>";
			document.getElementById('slideWindow').innerHTML += "<p><span class='lEOCCert2'>Hit 'OK' to return to the course outline</span>.</p>";
			
			document.getElementById('slideWindow').innerHTML += "<div id='EOCStartButton' class='divQuestionNext' tabIndex='3'><span class='lEOCButtonOK'>OK</span></div>";		
						
			/*** CONVERT TEXT TO THE SELECTED LANG: ***/
			change_text_language("EOC.xml");	
			
			/*** ADD ONCLICK FUNCTION TO RETURN TO THE COURSE OUTLINE: ***/
			document.getElementById("EOCStartButton").onclick = function () {
				//window.location = "main.html?cbtusername="+user.username;
				window.location = "main.html?cbtusername="+user.username+"&lang="+user_language;
			}
			
			document.getElementById('mainDiv').focus();			
		}
		else
		{
		
			/***
			LOAD ELEMENTS INTO MAIN:
			BUILD QUIZ ARRAY:
			ADD loadQuestion to buttons
			***/
			
			/*
			var eocQuiz = new getEOCQuiz(pageNode);
			eocQuiz.loadData();		
			*/		
			
			eocQuizObj = new EOCQuiz();
			eocQuizObj.loadData(chapNum);		
						
		}
		try{
		/*** SET THE LAST PAGE VIEWED TO THIS PAGE_NUM:	***/
		setDataValue("lpv", xmlDoc.getElementsByTagName("page")[pageNode].getAttribute("id"));
		courseMessage("LPV SET",5)
		/*
		TODO:
		IF SET DATA FAILED SHOW ERROR:
		*/	
		}catch(e){
			
			courseMessage(e,1);
		}
	}
	
	else
	{
		
		try{
		/*** SET THE LAST PAGE VIEWED TO THIS PAGE_NUM:	***/
		setDataValue("lpv", xmlDoc.getElementsByTagName("page")[pageNode].getAttribute("id"));
		courseMessage("LPV SET",5)
		/*
		TODO:
		IF SET DATA FAILED SHOW ERROR:
		*/	
		}catch(e){
			
			courseMessage(e,1);
		}
		
		/** ON EACH SLIDE LOAD: ***/
		/* GET THE DISPLAY TIME: */
	
		/*** RESET ANIMATIONS AND SET SLIDE TITLE ANIMATION: ***/
		if ("quiz" === xmlDoc.getElementsByTagName("page")[pageNode].getAttribute("type")){
			titleDisplayTime = 0;
		}
		
		resetSlideAnimations(slideTitle, titleDisplayTime);
			
		/*** Show the fancy slide bevel div ***/
		showSlideBevel();
	
		/*** LOAD THE STANDARD ELEMENTS - Title, Narration, Audio: ***/
		/*
		document.getElementById('slideTitle').innerHTML = xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("title")[0].childNodes[0].nodeValue;
		*/
		document.getElementById('slideTitle').innerHTML = "";
				
		/*** ***/		
		
		/* SET THE NARRATION WINDOW TEXT: */
		var narration_text;
		if (xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("narration")[0].getElementsByTagName(user_language)[0] !== undefined) {
			narration_text = xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("narration")[0].getElementsByTagName(user_language)[0].childNodes[0].nodeValue;
		} else {
			if(xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("narration")[0].getElementsByTagName(default_language)[0] !== undefined)
			{
				narration_text = xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("narration")[0].getElementsByTagName(default_language)[0].childNodes[0].nodeValue;		
			} else {
				narration_text = xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("narration")[0].childNodes[0].nodeValue;		
			}				
		}
		
		courseMessage("Notes: "+xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("notes")[0],5);
		
		/*** SHOW ANY NOTES FOR YOW USERS ***/
		if ((user.company).toUpperCase() == "YOW TEST" && xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("notes")[0] !== undefined)
		{
			narration_text = "<span style='color: red;'>[<i>"+xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("notes")[0].childNodes[0].nodeValue +"</i>]</span><br><br>"+ narration_text;
		}
		document.getElementById('narrationWindow').innerHTML = narration_text;
		$("#narrationWindow").scrollTop(0);
		
		/*** SET THE ADIO ***/
		/* ALLOW OGG */
		/* WHAT IF AUDIO NOT FOUND? */
		//console.log("Custom Timeline: "+xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("audio")[0].getAttribute("customTimeline"));
		audio_src = "";
		audio_node = xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("audio")[0];		
		var audioFile;
		if (audio_node.childNodes[0] != undefined) {
			audioFile = audio_node.childNodes[0].nodeValue;
		}
		if(audioFile) {
			var fileTypeSplit = audioFile.lastIndexOf("."); 
			if (fileTypeSplit != -1 && user_language!=default_language && course.multilanguage != "1") audioFile = audioFile.substr(0, fileTypeSplit) + "_"+user_language+"."+ audioFile.substr(fileTypeSplit + 1);
			//console.log(audioFile);
			/* CHECK TO SEE IF FRENCH AUTO EXISTS - IF NOT USE DEFAULT AUDIO FILE? */
			audio_src = assetURL+"module_"+chapNum+"/audio/"+audioFile;
		} else {
			audio_src = "";			
		}
		
		/*console.log("initial audio src: " + audio_src);*/
		if(fileExists(audio_src)) {
			courseMessage("Slide Audio File Found: "+audio_src,4);
			addAsset("slideAudio", audio_src, "audio");
		} else {

			//Warning! This slide is missing the audio file.

			if (xmlDoc.getElementsByTagName("page")[pageNode].getAttribute("type") === "quiz") {

				//Quizes don't need a fallback audio message so don't play anything
				document.getElementById('mediaAudio').innerHTML = "<source id='mediaAudioSource' src='' type='audio/mp3'>"
				mediaPlayer.load();

			}
			else{

				//Play a default 6 seconds empty sound (long enought for the slide title to animate)
				addAsset("slideAudio", global.courseFilesPath+"audio/SILENCE_6_SEC.mp3", "audio");

				//Cancel the auto nav for this slide only, this will stop the auto-nav to go to the next page automatically
				autoNavCalled = true;

				/*** SHOW MISSING AUDIO FOR YOW USERS ***/
				if ((user.company).toUpperCase() == "YOW TEST" )
				{
					narration_text =  "<span style='color: red;'>[<i>MISSING AUDIO</i>]</span><br><br>"+ narration_text;
					document.getElementById('narrationWindow').innerHTML = narration_text;
					$("#narrationWindow").scrollTop(0);
				}
				
			}

		}
		
		customTimeline = xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("audio")[0].getAttribute("customTimeline");
		if(customTimeline != undefined && !fileExists(audio_src)) {
			/* SET TIMELINE VALUES */
			tickerOn = true;
			elapsedTime = 0;
			totalTime = customTimeline;
		} else {
			tickerOn = false;
		}
		
		//document.getElementById('mediaAudio').innerHTML = "<source id='mediaAudioSource' src='"+audio_src+"' type='audio/mp3'>";
		/*document.getElementById('media-audio-source').setAttribute("src", );*/
		
		/*** UPDATE PROGRESS WINDOW POSITION: ***/
		document.getElementById('currPage').innerHTML = parseInt(chapterArrayPoss)+1;
		document.getElementById('totalPages').innerHTML = chapterArray.length;
				
		//OLD CODE
		///*** SET THE NEXT/PREV BUTTONS TO NEXT PREV PAGE NODES: ***/
		//if (pageNode === xmlDoc.getElementsByTagName("page").length-1) {
		//	/*** Last Page: Next BUTTON Should Return to the Course Outline? ***/
		//	document.getElementById("nextButton").setAttribute("onclick", "alert('Last Page - This should go back to Course Outline'); console.log('Pausing media cause last slide cant go to next'); mediaPlayer.pause(); return false; ");
		//	setNextButtonDisabled(true);
		//} 
		//else 
		//{
		//	/*** Set Next Button: ***/
		//	document.getElementById("nextButton").setAttribute("onclick", "loadSlide("+chapNum+", \""+xmlDoc.getElementsByTagName("page")[pageNode+1].getAttribute("id")+"\"); return false; ");
		//	setNextButtonDisabled(false);
		//}
		//if(pageNode === 0) 
		//{
		//	/*** First Slide: Disable Previous Button: ***/
		//	document.getElementById("prevButton").setAttribute("onclick", "loadSlide("+chapNum+", 0); return false; ");
		//	setPreviousButtonDisabled(true);
		//} 
		//else 
		//{
		//	/*** Set Prev Button: ***/
		//	document.getElementById("prevButton").setAttribute("onclick", "loadSlide("+chapNum+", \""+xmlDoc.getElementsByTagName("page")[pageNode-1].getAttribute("id")+"\"); return false; ");
		//	setPreviousButtonDisabled(false);
		//}
		
		/*** SET THE NEXT/PREV BUTTONS TO NEXT PREV PAGE NODES: ***/
		//setNextPage(xmlDoc, pageNode, chapNum);
		//setPreviousPage(xmlDoc, pageNode, chapNum);
		setNextPage(chapNum,chapterArrayPoss);
		setPreviousPage(chapNum,chapterArrayPoss);
			
		if ("quiz" === xmlDoc.getElementsByTagName("page")[pageNode].getAttribute("type")){
			/**********************************************************
				INT QUIZ:
			***********************************************************/
			
			/*** DISABLE THE NEXT BUTTON: ***/
			setNextButtonDisabled(true);
			
			/*** SET THE Z-INDEX FOR THE STAGE ***/
			document.getElementById('slideWindow').style.zIndex='5000';
			
			/*** HIDE COURSE BUTTONS ***/
			hideCourseButtons();
			
			/*** ADD THE QUESTION DIVS TO THE SLIDE: ***/
			loadQuestionDivs();
			
			/*** LOAD THE QUESTION DATA INTO QUESTION OBJECT USING THE QUESTION ID: ***/
			var question = new Question();
			question.loadData(xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("slide")[0].childNodes[0].nodeValue);


			//POPUP FOR SLIDE REFERENCE SECTION START
			//if (slideXml != undefined) {
			//	// create the popup object to display and then load the XML with the module index
			//	var slidePopupManager = new SlidePopupManager();
			//	slidePopupManager.loadSlideReference(slideXml, question.slide_ref_id);

			//	// create a button that will open the popup
			//	if (question.slide_ref_id != null) {
			//		var openLabel; user_language == "FRENCH" ? openLabel = "Ouvrir la diapositive" : openLabel = "Open Slide";
			//		document.getElementById('narrationWindow').innerHTML += "<div id='btnOpenSlideRef' class='popupButton' style='padding:4px;font-size:0.9em;'>" + openLabel + "</div>";
			//		document.getElementById('btnOpenSlideRef').addEventListener("click", function () {
			//			slidePopupManager.displaySlidePopup();
			//		})
			//	}
			//}
			//POPUP FOR SLIDE REFERENCE SECTION END


			/*** DISPLAY THE QUESTION TO THE SCREEN: ***/
			//questionDisplay(question);
		} 
		else {
			
			/*** SHOW COURSE BUTTONS ***/
			showCourseButtons();
			
			var slide_file = xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("slide")[0].childNodes[0].nodeValue;
			var fileTypeSplit = slide_file.lastIndexOf("."); 
			
			var fileMultilingual = xmlDoc.getElementsByTagName("page")[pageNode].getElementsByTagName("slide")[0].getAttribute("multilingual");			
			if (fileTypeSplit != -1 && user_language!=default_language && fileMultilingual==1  && course.multilanguage != "1" ) slide_file = slide_file.substr(0, fileTypeSplit) + "_"+user_language+"."+ slide_file.substr(fileTypeSplit + 1);
			
			/* WHAT IF SLIDE FILE NOT FOUND? */
			
			if ("advanced" === xmlDoc.getElementsByTagName("page")[pageNode].getAttribute("type")) 
			{
				/**********************************************************
					ANIMATION/SPECIAL FILE PAGE:
				***********************************************************/
				/*** LOAD HTML INTO DIV: ***/
				courseMessage("Advanced Slide File to Load: "+slide_file,3);
				/* Check to see if content exists? */

				var slideContent = loadTextFile(assetURL+"module_"+chapNum+"/"+slide_file);
				
				document.getElementById("slideWindow").innerHTML = slideContent;
				
				/*** EXECUTE THE INCLUDED JAVASCRIPT - PUT IN TRY CATCH INCASE SLIDE HAS NO JS: ***/
				try {
					var slideJS = document.getElementById("slideJS").innerHTML;
					jQuery.globalEval(slideJS);
				} catch (e) { 
					courseMessage("There is no Slide JS: "+e,1);
				}
			} 
			else 
			{
			
				/**********************************************************
					STANDARD PAGE:
				***********************************************************/	
				/*** LOAD IMAGE INTO SLIDE DIV: ***/
				var image_src = assetURL+"module_"+chapNum+"/images/"+slide_file;
				courseMessage("Slide Image File to Load: "+image_src,3);
				if(fileExists(image_src)) {
					addAsset("slideImg", image_src, "img");	
				} else {
					addAsset("slideImg", assetURL+global.courseFilesPath+"images/img_not_found.jpg", "img");
				}
			}
		}
		
		/*** END LOADING SCREEN ***/
		startPreload();			
	}
		
	document.getElementById("mainDiv").focus();
	
	///*** SET THE LAST PAGE VIEWED TO THIS PAGE_NUM:	***/
	//setDataValue("lpv", xmlDoc.getElementsByTagName("page")[pageNode].getAttribute("id"));
	///*
	//TODO:
	//IF SET DATA FAILED SHOW ERROR:
	//*/
	
	courseMessage("END Load Slide [chapNum : "+chapNum+" chapterArrayPoss: "+chapterArrayPoss&"]",2,1);
	
}

function displayEOCStart() {
	/*var xmlDoc = loadXMLDoc("quiz_questions/fp_quiz_questions.xml");*/
	//console.log("EOC obj chap: "+eocQuizObj.eocChapter);
	//console.log("returnedArray = " + eocQuizObj.returnedArray);
	//console.log("mixedArray = " + eocQuizObj.mixedArray);
	
	document.getElementById('slideWindow').innerHTML += "<p><span class='lEOC1'>Welcome to the End of Module Quiz</span>.</p>";
	document.getElementById('slideWindow').innerHTML += "<p><span class='lEOC2'>To pass the quiz you will need to achieve at least</span> <span class='specialText'>"+user.quizThresh+"%</span>.  <span class='lEOC3'>If you get lower than</span> <span class='specialText'>"+user.quizThresh+"%</span> <span class='lEOC4'>you will have to take the module over again and re-do the quiz until you pass</span>.</p>";
	document.getElementById('slideWindow').innerHTML += "<p><span class='lEOC5'>You can take a quiz as many times as required, however, when you have completed the entire course, your Statistic and Performance Record will indicate how many times you took each quiz before passing</span>.</p>";
	document.getElementById('slideWindow').innerHTML += "<p><span class='lEOC6'>This quiz has a total of</span> <span class='specialText'>"+eocQuizObj.mixedArray.length+"</span> <span class='lEOC7'>questions</span>.</p>";
	document.getElementById('slideWindow').innerHTML += "<h2 ><span class='lEOC8>Good luck!</span></h2>";
	document.getElementById('slideWindow').innerHTML += "<div id='EOCStartButton' class='divQuestionNext' tabIndex='3'><span class='lEOCStart'>Start</span></div>";		
	
	/*** CONVERT TEXT TO THE SELECTED LANG: ***/
	change_text_language("EOC.xml");
	
	/*** ADD THE EOC AUDIO: ***/
	document.getElementById('slideWindow').innerHTML += "<audio id='eocAudio' autoplay>";
	document.getElementById('slideWindow').innerHTML += "<source id='eocAudioSource' src='' type='audio/mpeg'>";
	document.getElementById('slideWindow').innerHTML += "</audio> ";
	
	var audio_src = "";
	var audioFile = "EOC.mp3";
	var fileTypeSplit = audioFile.lastIndexOf("."); 
	if (fileTypeSplit != -1 && user_language!=default_language && course.multilanguage != "1") audioFile = audioFile.substr(0, fileTypeSplit) + "_"+user_language+"."+ audioFile.substr(fileTypeSplit + 1);
	audio_src = global.courseFilesPath+"audio/"+audioFile;

	document.getElementById('eocAudio').innerHTML = "<source id='eocAudioSource' src='"+audio_src+"' type='audio/mp3'>"

	var audioElement = document.getElementById('eocAudio');
	audioElement.load();
	
	/*** ADD ONCLICK FUNCTION TO START BUTTON TO LOAD FIRST QUESTION: ***/
	document.getElementById("EOCStartButton").onclick = function () {
			document.getElementById('slideWindow').className = "EOCInstructionsWindow";
			
			/*** SHOW THE ELEMENTS AND LOAD QUESTION DATA: ***/
			loadQuestionDivs();	
			
			/*** BUILD THE QUESTION BASED ON NEXT EOC QUESTION: ***/
			var question = new Question();
			question.EOCQuestion = true;
			question.loadData(eocQuizObj.mixedArray[eocQuizObj.currentQuestion]);
			
			eocQuizObj.currentQuestion++; //INCREASE THE CURRENT QUESTION TO NEXT QUESTION.
			
	}
	document.getElementById('mainDiv').focus();
}



function setNextPage(chapNum, chapterArrayPoss){
chapterArrayPoss = parseInt(chapterArrayPoss);
	if (chapterArrayPoss+1 >= chapterArray.length ) {
		/*** Last Page: Next BUTTON Should Return to the Course Outline? ***/
		//BMC: IS THIS NEEDED STILL?
		//note to do-if diffrent version do not have the same LASTPAGe what happnds...
		
		document.getElementById("nextButton").setAttribute("onclick", "alert('Last Page - This should go back to Course Outline'); mediaPlayer.pause(); return false; ");
		setNextButtonDisabled(true);
	} 
	else{
		document.getElementById("nextButton").setAttribute("onclick", "loadSlide("+chapNum+", \""+(chapterArrayPoss+1)+"\"); return false; ");
		document.getElementById("nextButton").setAttribute("onclick", "loadSlide("+chapNum+", \""+(chapterArrayPoss+1)+"\"); return false; ");
		setNextButtonDisabled(false);
	}
	

}
function setPreviousPage(chapNum, chapterArrayPoss){
	chapterArrayPoss = parseInt(chapterArrayPoss);
	if (chapterArrayPoss <= 0) {
		/*** First Slide: Disable Previous Button: ***/
		document.getElementById("prevButton").setAttribute("onclick", "loadSlide("+chapNum+", 0); return false; ");
		setPreviousButtonDisabled(true);
	} 	
	else{
		document.getElementById("prevButton").setAttribute("onclick", "loadSlide("+chapNum+", "+(chapterArrayPoss-1)+"); return false; ");
		setPreviousButtonDisabled(false);
	}
}


function checkAutoNav(){
	courseMessage("check user.disable_autonav: "+user.disable_autonav,4);
	courseMessage("check user.autonav: "+user.autonav,4);
	if( user.autonav && !nextDisabled && !autoNavCalled ) {
		autoNavCalled = true;
		document.getElementById("nextButton").disabled = true;
		setTimeout(function() {
    

			courseMessage("Calling Autonav",3);
					
			var nextSlide = document.getElementById("nextButton").getAttribute("onclick")
			nextSlide = nextSlide.replace(" return false;", "")
			//console.log(nextSlide)
			eval(nextSlide);
		}, 2000); /* Pause for 1.5 seconds before calling next slide with autonav */
	}
	else if( (!user.autonav ) && !nextDisabled && !autoNavCalled ){
		autoNavCalled = true;
		document.getElementById("nextButton").className += (" nextFlash");
	}
}

function setAutoNavDisplay() {
	courseMessage("display user.disable_autonav: "+user.disable_autonav,4);
	courseMessage("display user.autonav: "+user.autonav,4);
	if(user.autonav) {
		document.getElementById('autoNavStatus').innerHTML = '&#10004;';
	} else { 
		document.getElementById('autoNavStatus').innerHTML = '&#10008;';
	}
	
	if(user.disable_autonav) {
		document.getElementById('autoNavDiv').style.display = "none";
	}
}

/*** ADD A CONFIRMATION DIALOG WHEN LEAVING THE COURSE - Turned off for Links & Refresh: ***/
$(document).on('mousedown', 'a[href]', offBeforeUnload)
	.on('mouseleave', 'a[href]', function () {
	$(window).on('beforeunload', windowBeforeUnload);
});



function offBeforeUnload(event) {
	$(window).off('beforeunload');
}

function windowBeforeUnload() {
	/* TEMPORARILY DISABLED DURING DEV
	return "Are you sure you want to close the course?";     
	*/
}

$(window).on('beforeunload', windowBeforeUnload);

/*** ADD HOTKEY SHORTCUTS: ***/

var mainMenuSelection = -1;

// define a handler
function doc_keyUp(e) {
	var handled = false;
	
	courseMessage("Key Press: " + e.keyCode,5);
    // this would test for whichever key is 40 and the ctrl key at the same time
    //if (e.ctrlKey && e.keyCode == 40) {
        // call your function to do the thing
      //  pauseSound();
    //}
	


	//if overlay is open; and focus on item on mainDiv, do nothing
	if (document.getElementById("mainOverlay").style.display == "block"){
		var popupDiv = $('div').filter(function() {	return this.id.toLowerCase().indexOf('popup') > -1;	});
		if(!$(e.target).closest(popupDiv).length){
				e.target.blur();	//blur next tabbed element
				popupDiv.focus();	//focus on element on pop-up
		}
	}
	
	/* ENTER KEY PRESS - EXECUTE THE SELECTED ELEMENT ONCLICK */
	if(e.keyCode == 13) {		
		if(document.activeElement!= undefined) {
			courseMessage(document.activeElement.nodeName.toLowerCase());
			if(document.activeElement.nodeName.toLowerCase() != "a" && document.activeElement.nodeName.toLowerCase() != "button") {
					courseMessage("running onlick",5);
					document.activeElement.click();
			}		
		}
	}
	
	/* RIGHT: GO TO PREV */
	if(e.keyCode == 37) {		
		if(!prevDisabled && document.getElementById("prevButton") != undefined) {		
			//console.log("Using hot key to go prev.... need a delay?")
			var nextSlide = document.getElementById("prevButton").getAttribute("onclick")
			nextSlide = nextSlide.replace(" return false;", "")
			//console.log(nextSlide)
			eval(nextSlide);
		}
	}
	/* LEFT: GO TO NEXT */
	if(e.keyCode == 39) {		
		if(!nextDisabled && document.getElementById("nextButton") != undefined) {		
			//console.log("Using hot key to go next.... need a delay?")
			var nextSlide = document.getElementById("nextButton").getAttribute("onclick")
			nextSlide = nextSlide.replace(" return false;", "")
			//console.log(nextSlide)
			eval(nextSlide);
		}
	}
	
	/* M: Open Main Menu/Cycle through the Main Menu Links */		
	if(e.keyCode == 77) {		
		var menu = document.getElementById('mainMenuLinks');
		var links = menu.getElementsByTagName('a');		
		if (mainMenuSelection == -1 || mainMenuSelection == undefined) {
			mainMenuSelection = 0;
		} else if (mainMenuSelection==links.length-1) {
			/* IF AT LAST LINK AND Key HIT GO TO TOP */
			mainMenuSelection = 0;
		} else {
			mainMenuSelection = mainMenuSelection+1;
		}		
		var link = links[mainMenuSelection];
		link.focus();		
		//console.log(mainMenuSelection+" "+link);		
		//console.log(document.getElementById("mainMenuLinks").childNodes.length);		
		//console.log(document.getElementById("mainMenuLinks").childNodes[0]);
	}
	
	/* UP: SELECT NEXT MENU LINK */
	//if(e.keyCode == 38) {	
	//	var menu = document.getElementById('mainMenuLinks');
	//	var links = menu.getElementsByTagName('a');		
	//	if (mainMenuSelection == -1 || mainMenuSelection == undefined ) {
	//		mainMenuSelection = links.length-1;
	//	} else if (mainMenuSelection==0){
			/* IF AT TOP LINK AND UP HIT, GO TO LAST LINK */
	//		mainMenuSelection = links.length-1;		
	//	} else	{
	//		mainMenuSelection = mainMenuSelection-1;
	//	}		
	//	var link = links[mainMenuSelection];
	//	link.focus();			
	//	console.log(mainMenuSelection+" "+link);		
		//console.log(document.getElementById("mainMenuLinks").childNodes.length);		
	//}	
	
	/* P: Reset Slide */
	if(e.keyCode == 80) {		
		if(document.getElementById("replayButton") != undefined) {		
			//console.log("Using hot key to go next.... need a delay?")
			var resetSlide = document.getElementById("replayButton").getAttribute("onclick")
			//console.log(nextSlide)
			eval(resetSlide);
		}
	}
	/* SPCBAR: Pause | Play */
	if(e.keyCode == 32) {		
		if(document.getElementById("playPauseButton") != undefined) {		
			var pausePlayBtnClick = document.getElementById("playPauseButton").getAttribute("onclick")
			//console.log(nextSlide)
			eval(pausePlayBtnClick);
		}
	}
	
	/* +: GO Increase Volume */
	if(e.keyCode == 187 || e.keyCode == 107) {		
		if(volumeBar != undefined) {		
			if(volumeBar.value < 1) {
				volumeBar.value = volumeBar.value + 0.1;
				mediaPlayer.volume = volumeBar.value;
				/* UNMUTE? */
			}
		}
	}
	/* -: GO Decreate Volume */
	if(e.keyCode == 189 || e.keyCode == 109) {			
		if(volumeBar != undefined) {		
			if(volumeBar.value > 0) {				
				volumeBar.value = volumeBar.value-0.1;
				mediaPlayer.volume = volumeBar.value;
			}
		}
	}
	/* 0: Mute */
	if(e.keyCode == 48 || e.keyCode == 96) {		
		if(document.getElementById("muteButton") != undefined) {		
			//console.log("Using hot key to go next.... need a delay?")
			var muteAudio = document.getElementById("muteButton").getAttribute("onclick")
			//console.log(nextSlide)
			eval(muteAudio);
		}
	}	
	
	/* N: Focus Nav/LPV no/Glossary Def windows */
	if(e.keyCode == 78) {	
		courseMessage(document.getElementById("glossaryPopUp").style.display,5);
		if(document.getElementById("glossaryPopUp").style.display == "block") { 
			document.getElementById("dictionaryDefinition").focus();
		} else if (document.getElementById("lpvPopup").style.display == "block") {	
			document.getElementById("lpvNO").focus();
		} else if (document.getElementById("narrationWindow") != undefined) {		
			//console.log("Using hot key to go next.... need a delay?")
			document.getElementById("narrationWindow").focus();
		}
	}
	
	/* Y: LPV yes */
	if(e.keyCode == 89) {		
		if(document.getElementById("lpvPopup").style.display == "block") {		
			document.getElementById("lpvYES").focus();
		}
	}
	
//try to disable the highlight of old focus element
	try{
		document.getElementsByClassName('tabFocus')[0].className = document.getElementsByClassName('tabFocus')[0].className.replace(/\btabFocus\b/,'')
	}catch(err){}
	//puts highligh on focus element
	try{
		if(document.activeElement.className  != 'mainMenuLink' && document.activeElement.className  !='mainDiv'){
		//console.log(document.activeElement.className);
		document.activeElement.className += " tabFocus";//add focus highlight to element
		}
	}catch(err){
		
		courseMessage(err,1);
	}
	
	/* esc: Closs Gloss/as lpvNO */
	if(e.keyCode == 27) {		
		if(document.getElementById("glossaryPopUp").style.display == "block") { 
			closeGlossary();
		}
		if(document.getElementById("lpvPopup") != undefined){
			if(document.getElementById("lpvPopup").style.display == "block") {		
				document.getElementById("lpvNO").click();
			
			}
		}
		
		var menu = document.getElementById('mainMenuLinks');
		var links = menu.getElementsByTagName('a');
		for (var i=0; i<links.length; i++) {
			links[i].blur();
		}
	}	
	
	/* Keys 1-9 activate Quiz Questions or Select Chapter from TOC */
	if(e.keyCode == 49 || e.keyCode == 97) {		
		handleNumKey(1);
	}	
	if(e.keyCode == 50 || e.keyCode == 98) {		
		handleNumKey(2);
	}	
	if(e.keyCode == 51 || e.keyCode == 99) {		
		handleNumKey(3);
	}	
	if(e.keyCode == 52 || e.keyCode == 100) {		
		handleNumKey(4);
	}	
	if(e.keyCode == 53 || e.keyCode == 101) {		
		handleNumKey(5);
	}	
	if(e.keyCode == 54 || e.keyCode == 102) {		
		handleNumKey(6);
	}	
	if(e.keyCode == 55 || e.keyCode == 103) {		
		handleNumKey(7);
	}	
	if(e.keyCode == 56 || e.keyCode == 104) {		
		handleNumKey(8);
	}	
	if(e.keyCode == 57 || e.keyCode == 105) {		
		handleNumKey(9);
	}	
	
	if(handled) {
		/* Surpress "double action" if event handled */
		//e.preventDefault();
	}	
}
// register the handler 
document.addEventListener('keyup', doc_keyUp, false);

/*** FOCUS MAIN MENU LINK OPEN/KEEP UP MAINMENU LIST: ***/
function focusLink(isOnFocus)
{
    if (isOnFocus)
      document.getElementById('mainMenuLinks').className = "mainMenuLinks-Focus";
    else
      document.getElementById('mainMenuLinks').className = "mainMenuLinks";
	
}

function handleNumKey(num) {
	/* IF QUIZ SELECT QUIZ */
	if(  document.getElementById('quiz')!=undefined) {
		num = num-1;
		/* SET THE ANSWER INDEX: */
		for(i = 0; i<4; i++) {						
			document.getElementById("divQuestion"+i).style.backgroundColor = "#AEC7FF";	
			document.getElementById("divQuestion"+i).style.border = "1px solid #31639C";
			document.getElementById("divQuestion"+i).style.color = "#003D79";	
			
			document.getElementById("divQuizLetter"+i).style.backgroundColor = "#AEC7FF";	
			document.getElementById("divQuizLetter"+i).style.border = "1px solid #31639C";
			document.getElementById("divQuizLetter"+i).style.color = "#003D79";		
		}

		if(document.getElementById("divQuestion"+num)!=undefined) {
			if(document.getElementById("divQuestion"+num).style.display != "none" ) 
			{
				answerIndex = num;
				/* SELECT/HIGHLIGHT THE SELECTED ANSWER */
				document.getElementById("divQuestion"+answerIndex).style.backgroundColor = "#31639C";	
				document.getElementById("divQuestion"+answerIndex).style.border = "1px solid #FFF";
				document.getElementById("divQuestion"+answerIndex).style.color = "#FFF";	
				
				document.getElementById("divQuizLetter"+answerIndex).style.backgroundColor = "#31639C";	
				document.getElementById("divQuizLetter"+answerIndex).style.border = "1px solid #FFF";
				document.getElementById("divQuizLetter"+answerIndex).style.color = "#FFF";	
					
				/* SHOW THE SUBMIT BUTTON: */
				document.getElementById("submitAnswer").style.display = "block";
				document.getElementById("submitAnswer").focus();
			}
		}
		
		
	}
	/* IF TOC SELECT CHAPTER */
	if(document.getElementById('tocTable')!=undefined) {
		courseMessage("Keypress chapter num",5);
		if(  document.getElementById('tdChapter'+num)!=undefined) {	
			try {
				var chapterStart = document.getElementById('tdChapter'+num).getAttribute("onclick")
				chapterStart = chapterStart.replace(" return false;", "");
				//console.log(nextSlide)
				eval(chapterStart);			
			} catch (e) {
				courseMessage("Error loading chapter with key press"+num+ "["+e+"]",1);
			}
		}
	}
}

